@@ -18,10 +18,12 @@
 #include "ash/focus_cycler.h"
 #include "ash/ime/ime_controller.h"
 #include "ash/ime/ime_switch_type.h"
+#include "ash/magnifier/docked_magnifier_controller.h"
 #include "ash/magnifier/magnification_controller.h"
 #include "ash/media_controller.h"
 #include "ash/multi_profile_uma.h"
 #include "ash/new_window_controller.h"
+#include "ash/public/cpp/ash_features.h"
 #include "ash/public/cpp/config.h"
 #include "ash/resources/vector_icons/vector_icons.h"
 #include "ash/root_window_controller.h"
@@ -260,36 +262,20 @@ void HandleLaunchLastApp() {
 }
 
 void HandleMediaNextTrack() {
+  base::RecordAction(UserMetricsAction("Accel_Media_Next_Track"));
   Shell::Get()->media_controller()->HandleMediaNextTrack();
 }
 
 void HandleMediaPlayPause() {
+  base::RecordAction(UserMetricsAction("Accel_Media_PlayPause"));
   Shell::Get()->media_controller()->HandleMediaPlayPause();
 }
 
 void HandleMediaPrevTrack() {
+  base::RecordAction(UserMetricsAction("Accel_Media_Prev_Track"));
   Shell::Get()->media_controller()->HandleMediaPrevTrack();
 }
 
-void HandleMoveWindowBetweenDisplays(AcceleratorAction action) {
-  DisplayMoveWindowDirection direction;
-  if (action == MOVE_WINDOW_TO_ABOVE_DISPLAY) {
-    base::RecordAction(UserMetricsAction("Accel_Move_Window_To_Above_Display"));
-    direction = DisplayMoveWindowDirection::kAbove;
-  } else if (action == MOVE_WINDOW_TO_BELOW_DISPLAY) {
-    base::RecordAction(UserMetricsAction("Accel_Move_Window_To_Below_Display"));
-    direction = DisplayMoveWindowDirection::kBelow;
-  } else if (action == MOVE_WINDOW_TO_LEFT_DISPLAY) {
-    base::RecordAction(UserMetricsAction("Accel_Move_Window_To_Left_Display"));
-    direction = DisplayMoveWindowDirection::kLeft;
-  } else {
-    DCHECK(action == MOVE_WINDOW_TO_RIGHT_DISPLAY);
-    base::RecordAction(UserMetricsAction("Accel_Move_Window_To_Right_Display"));
-    direction = DisplayMoveWindowDirection::kRight;
-  }
-  HandleMoveActiveWindowToDisplay(direction);
-}
-
 void HandleToggleMirrorMode() {
   base::RecordAction(UserMetricsAction("Accel_Toggle_Mirror_Mode"));
   bool mirror = !Shell::Get()->display_manager()->IsInMirrorMode();
@@ -385,7 +371,7 @@ void HandleRotateScreen() {
       Shell::Get()->display_manager()->GetDisplayInfo(display.id());
   Shell::Get()->display_configuration_controller()->SetDisplayRotation(
       display.id(), GetNextRotation(display_info.GetActiveRotation()),
-      display::Display::ROTATION_SOURCE_USER);
+      display::Display::RotationSource::USER);
 }
 
 void HandleRestoreTab() {
@@ -866,34 +852,30 @@ void HandleVolumeUp(mojom::VolumeController* volume_controller,
     volume_controller->VolumeUp();
 }
 
-bool CanHandleMagnifyScreen() {
-  return Shell::Get()->magnification_controller()->IsEnabled();
+bool CanHandleActiveMagnifierZoom() {
+  return Shell::Get()->magnification_controller()->IsEnabled() ||
+         (features::IsDockedMagnifierEnabled() &&
+          Shell::Get()->docked_magnifier_controller()->GetEnabled());
 }
 
-// Magnify the screen
-void HandleMagnifyScreen(int delta_index) {
+// Change the scale of the active magnifier.
+void HandleActiveMagnifierZoom(int delta_index) {
   // TODO(crbug.com/612331): Mash support.
   if (Shell::GetAshConfig() == Config::MASH) {
     NOTIMPLEMENTED();
     return;
   }
 
-  if (!Shell::Get()->magnification_controller()->IsEnabled())
+  if (Shell::Get()->magnification_controller()->IsEnabled()) {
+    Shell::Get()->magnification_controller()->StepToNextScaleValue(delta_index);
     return;
+  }
 
-  // TODO(yoshiki): Move the following logic to MagnificationController.
-  float scale = Shell::Get()->magnification_controller()->GetScale();
-  // Calculate rounded logarithm (base kMagnificationScaleFactor) of scale.
-  int scale_index =
-      std::round(std::log(scale) /
-                 std::log(MagnificationController::kMagnificationScaleFactor));
-
-  int new_scale_index = std::max(0, std::min(8, scale_index + delta_index));
-
-  Shell::Get()->magnification_controller()->SetScale(
-      std::pow(MagnificationController::kMagnificationScaleFactor,
-               new_scale_index),
-      true);
+  if (features::IsDockedMagnifierEnabled() &&
+      Shell::Get()->docked_magnifier_controller()->GetEnabled()) {
+    Shell::Get()->docked_magnifier_controller()->StepToNextScaleValue(
+        delta_index);
+  }
 }
 
 bool CanHandleTouchHud() {
@@ -1184,14 +1166,12 @@ bool AcceleratorController::CanPerformAction(
       return CanHandleDisableCapsLock(previous_accelerator);
     case LOCK_SCREEN:
       return CanHandleLock();
-    case MAGNIFY_SCREEN_ZOOM_IN:
-    case MAGNIFY_SCREEN_ZOOM_OUT:
-      return CanHandleMagnifyScreen();
-    case MOVE_WINDOW_TO_ABOVE_DISPLAY:
-    case MOVE_WINDOW_TO_BELOW_DISPLAY:
-    case MOVE_WINDOW_TO_LEFT_DISPLAY:
-    case MOVE_WINDOW_TO_RIGHT_DISPLAY:
-      return CanHandleMoveActiveWindowBetweenDisplays();
+    case MAGNIFIER_ZOOM_IN:
+    case MAGNIFIER_ZOOM_OUT:
+      return CanHandleActiveMagnifierZoom();
+    case MOVE_ACTIVE_WINDOW_BETWEEN_DISPLAYS:
+      return display_move_window_util::
+          CanHandleMoveActiveWindowBetweenDisplays();
     case NEW_INCOGNITO_WINDOW:
       return CanHandleNewIncognitoWindow();
     case NEXT_IME:
@@ -1417,11 +1397,11 @@ void AcceleratorController::PerformAction(AcceleratorAction action,
     case LOCK_SCREEN:
       HandleLock();
       break;
-    case MAGNIFY_SCREEN_ZOOM_IN:
-      HandleMagnifyScreen(1);
+    case MAGNIFIER_ZOOM_IN:
+      HandleActiveMagnifierZoom(1);
       break;
-    case MAGNIFY_SCREEN_ZOOM_OUT:
-      HandleMagnifyScreen(-1);
+    case MAGNIFIER_ZOOM_OUT:
+      HandleActiveMagnifierZoom(-1);
       break;
     case MEDIA_NEXT_TRACK:
       HandleMediaNextTrack();
@@ -1432,11 +1412,8 @@ void AcceleratorController::PerformAction(AcceleratorAction action,
     case MEDIA_PREV_TRACK:
       HandleMediaPrevTrack();
       break;
-    case MOVE_WINDOW_TO_ABOVE_DISPLAY:
-    case MOVE_WINDOW_TO_BELOW_DISPLAY:
-    case MOVE_WINDOW_TO_LEFT_DISPLAY:
-    case MOVE_WINDOW_TO_RIGHT_DISPLAY:
-      HandleMoveWindowBetweenDisplays(action);
+    case MOVE_ACTIVE_WINDOW_BETWEEN_DISPLAYS:
+      display_move_window_util::HandleMoveActiveWindowBetweenDisplays();
       break;
     case NEW_INCOGNITO_WINDOW:
       HandleNewIncognitoWindow();
