@@ -4,9 +4,12 @@
 
 #include "ash/accelerators/accelerator_controller.h"
 
+#include <utility>
+
 #include "ash/accelerators/accelerator_table.h"
 #include "ash/accessibility/accessibility_controller.h"
 #include "ash/accessibility/test_accessibility_controller_client.h"
+#include "ash/app_list/test/app_list_test_helper.h"
 #include "ash/ime/ime_controller.h"
 #include "ash/media_controller.h"
 #include "ash/public/cpp/ash_switches.h"
@@ -19,11 +22,11 @@
 #include "ash/shell_test_api.h"
 #include "ash/system/brightness_control_delegate.h"
 #include "ash/system/keyboard_brightness_control_delegate.h"
+#include "ash/system/power/power_button_controller_test_api.h"
 #include "ash/test/ash_test_base.h"
 #include "ash/test_media_client.h"
 #include "ash/test_screenshot_delegate.h"
 #include "ash/wm/lock_state_controller.h"
-#include "ash/wm/lock_state_controller_test_api.h"
 #include "ash/wm/panels/panel_layout_manager.h"
 #include "ash/wm/test_session_state_animator.h"
 #include "ash/wm/window_positioning_utils.h"
@@ -819,9 +822,6 @@ TEST_F(AcceleratorControllerTest, GlobalAccelerators) {
 }
 
 TEST_F(AcceleratorControllerTest, GlobalAcceleratorsToggleAppList) {
-  app_list::test::TestAppListPresenter test_app_list_presenter;
-  Shell::Get()->app_list()->SetAppListPresenter(
-      test_app_list_presenter.CreateInterfacePtrAndBind());
   AccessibilityController* controller =
       Shell::Get()->accessibility_controller();
 
@@ -830,12 +830,12 @@ TEST_F(AcceleratorControllerTest, GlobalAcceleratorsToggleAppList) {
       ProcessInController(ui::Accelerator(ui::VKEY_LWIN, ui::EF_NONE)));
   RunAllPendingInMessageLoop();
   EXPECT_EQ(ui::VKEY_LWIN, GetCurrentAccelerator().key_code());
-  EXPECT_EQ(0u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(false);
 
   EXPECT_TRUE(ProcessInController(
       CreateReleaseAccelerator(ui::VKEY_LWIN, ui::EF_NONE)));
   RunAllPendingInMessageLoop();
-  EXPECT_EQ(1u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(true);
   EXPECT_EQ(ui::VKEY_LWIN, GetPreviousAccelerator().key_code());
 
   // When spoken feedback is on, the AppList should not toggle.
@@ -848,7 +848,7 @@ TEST_F(AcceleratorControllerTest, GlobalAcceleratorsToggleAppList) {
   controller->SetSpokenFeedbackEnabled(false, A11Y_NOTIFICATION_NONE);
   EXPECT_FALSE(controller->IsSpokenFeedbackEnabled());
   RunAllPendingInMessageLoop();
-  EXPECT_EQ(1u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(true);
 
   // Turning off spoken feedback should allow the AppList to toggle again.
   EXPECT_FALSE(
@@ -856,17 +856,17 @@ TEST_F(AcceleratorControllerTest, GlobalAcceleratorsToggleAppList) {
   EXPECT_TRUE(ProcessInController(
       CreateReleaseAccelerator(ui::VKEY_LWIN, ui::EF_NONE)));
   RunAllPendingInMessageLoop();
-  EXPECT_EQ(2u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(false);
 
   // The press of VKEY_BROWSER_SEARCH should toggle the AppList
   EXPECT_TRUE(ProcessInController(
       ui::Accelerator(ui::VKEY_BROWSER_SEARCH, ui::EF_NONE)));
   RunAllPendingInMessageLoop();
-  EXPECT_EQ(3u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(true);
   EXPECT_FALSE(ProcessInController(
       CreateReleaseAccelerator(ui::VKEY_BROWSER_SEARCH, ui::EF_NONE)));
   RunAllPendingInMessageLoop();
-  EXPECT_EQ(3u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(true);
 
   // When pressed key is interrupted by mouse, the AppList should not toggle.
   EXPECT_FALSE(
@@ -875,7 +875,7 @@ TEST_F(AcceleratorControllerTest, GlobalAcceleratorsToggleAppList) {
   EXPECT_FALSE(ProcessInController(
       CreateReleaseAccelerator(ui::VKEY_LWIN, ui::EF_NONE)));
   RunAllPendingInMessageLoop();
-  EXPECT_EQ(3u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(true);
 }
 
 TEST_F(AcceleratorControllerTest, MediaGlobalAccelerators) {
@@ -1037,10 +1037,11 @@ TEST_F(PreferredReservedAcceleratorsTest, AcceleratorsWithFullscreen) {
   ui::test::EventGenerator& generator = GetEventGenerator();
 
   // Power key (reserved) should always be handled.
-  LockStateControllerTestApi test_api(Shell::Get()->lock_state_controller());
-  EXPECT_FALSE(test_api.is_animating_lock());
+  PowerButtonControllerTestApi test_api(
+      Shell::Get()->power_button_controller());
+  EXPECT_FALSE(test_api.PowerButtonMenuTimerIsRunning());
   generator.PressKey(ui::VKEY_POWER, ui::EF_NONE);
-  EXPECT_TRUE(test_api.is_animating_lock());
+  EXPECT_TRUE(test_api.PowerButtonMenuTimerIsRunning());
 
   auto press_and_release_alt_tab = [&generator]() {
     generator.PressKey(ui::VKEY_TAB, ui::EF_ALT_DOWN);
@@ -1085,10 +1086,11 @@ TEST_F(PreferredReservedAcceleratorsTest, AcceleratorsWithPinned) {
   ui::test::EventGenerator& generator = GetEventGenerator();
 
   // Power key (reserved) should always be handled.
-  LockStateControllerTestApi test_api(Shell::Get()->lock_state_controller());
-  EXPECT_FALSE(test_api.is_animating_lock());
+  PowerButtonControllerTestApi test_api(
+      Shell::Get()->power_button_controller());
+  EXPECT_FALSE(test_api.PowerButtonMenuTimerIsRunning());
   generator.PressKey(ui::VKEY_POWER, ui::EF_NONE);
-  EXPECT_TRUE(test_api.is_animating_lock());
+  EXPECT_TRUE(test_api.PowerButtonMenuTimerIsRunning());
 
   // A pinned window can consume ALT-TAB (preferred), but no side effect.
   ASSERT_EQ(w1, wm::GetActiveWindow());
