@@ -37,12 +37,26 @@ void TestAccessibilityControllerClient::PlayShutdownSound(
 }
 
 void TestAccessibilityControllerClient::HandleAccessibilityGesture(
-    const std::string& gesture) {
+    ax::mojom::Gesture gesture) {
   last_a11y_gesture_ = gesture;
 }
 
 void TestAccessibilityControllerClient::ToggleDictation() {}
 
+void TestAccessibilityControllerClient::SilenceSpokenFeedback() {}
+
+void TestAccessibilityControllerClient::OnTwoFingerTouchStart() {}
+
+void TestAccessibilityControllerClient::OnTwoFingerTouchStop() {}
+
+void TestAccessibilityControllerClient::ShouldToggleSpokenFeedbackViaTouch(
+    ShouldToggleSpokenFeedbackViaTouchCallback callback) {
+  std::move(callback).Run(true);  // Passing true for testing.
+}
+
+void TestAccessibilityControllerClient::PlaySpokenFeedbackToggleCountdown(
+    int tick_count) {}
+
 int32_t TestAccessibilityControllerClient::GetPlayedEarconAndReset() {
   int32_t tmp = sound_key_;
   sound_key_ = -1;
