@@ -8,6 +8,7 @@
 
 #include "ash/focus_cycler.h"
 #include "ash/ime/ime_controller.h"
+#include "ash/keyboard/keyboard_observer_register.h"
 #include "ash/login/login_screen_controller.h"
 #include "ash/login/ui/layout_util.h"
 #include "ash/login/ui/lock_screen.h"
@@ -27,6 +28,7 @@
 #include "ash/system/tray/system_tray_notifier.h"
 #include "base/strings/string16.h"
 #include "base/strings/utf_string_conversions.h"
+#include "mojo/common/values_struct_traits.h"
 #include "ui/accessibility/ax_node_data.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/display/display.h"
@@ -155,6 +157,19 @@ views::Label* CreateInfoLabel() {
   return label;
 }
 
+keyboard::KeyboardController* GetKeyboardControllerForWidget(
+    const views::Widget* widget) {
+  keyboard::KeyboardController* keyboard_controller =
+      keyboard::KeyboardController::GetInstance();
+  if (!keyboard_controller)
+    return nullptr;
+
+  aura::Window* keyboard_window =
+      keyboard_controller->GetContainerWindow()->GetRootWindow();
+  aura::Window* this_window = widget->GetNativeWindow()->GetRootWindow();
+  return keyboard_window == this_window ? keyboard_controller : nullptr;
+}
+
 }  // namespace
 
 LockContentsView::TestApi::TestApi(LockContentsView* view) : view_(view) {}
@@ -198,7 +213,8 @@ LockContentsView::LockContentsView(
     : NonAccessibleView(kLockContentsViewName),
       data_dispatcher_(data_dispatcher),
       display_observer_(this),
-      session_observer_(this) {
+      session_observer_(this),
+      keyboard_observer_(this) {
   data_dispatcher_->AddObserver(this);
   display_observer_.Add(display::Screen::GetScreen());
   Shell::Get()->login_screen_controller()->AddLockScreenAppsFocusObserver(this);
@@ -238,6 +254,7 @@ LockContentsView::LockContentsView(
   top_header_->AddChildView(note_action_);
 
   OnLockScreenNoteStateChanged(initial_note_action_state);
+  Shell::Get()->AddShellObserver(this);
 }
 
 LockContentsView::~LockContentsView() {
@@ -253,6 +270,8 @@ LockContentsView::~LockContentsView() {
     Shell::Get()->metrics()->login_metrics_recorder()->RecordNumLoginAttempts(
         unlock_attempt_, false /*success*/);
   }
+  Shell::Get()->RemoveShellObserver(this);
+  keyboard_observer_.RemoveAll();
 }
 
 void LockContentsView::Layout() {
@@ -264,6 +283,14 @@ void LockContentsView::Layout() {
 }
 
 void LockContentsView::AddedToWidget() {
+  // Register keyboard observer after view has been added to the widget. If
+  // virtual keyboard is activated before displaying lock screen we do not
+  // receive OnVirtualKeyboardStateChanged() callback and we need to register
+  // keyboard observer here.
+  keyboard::KeyboardController* keyboard_controller = GetKeyboardController();
+  if (keyboard_controller)
+    keyboard_observer_.Add(keyboard_controller);
+
   DoLayout();
 
   // Focus the primary user when showing the UI. This will focus the password.
@@ -312,9 +339,15 @@ void LockContentsView::OnUsersChanged(
   opt_secondary_auth_ = nullptr;
   users_list_ = nullptr;
   rotation_actions_.clear();
+  users_.clear();
+
+  // If there are no users we have no UI to build.
+  if (users.empty()) {
+    LOG(ERROR) << "Empty user list received";
+    return;
+  }
 
   // Build user state list.
-  users_.clear();
   for (const mojom::LoginUserInfoPtr& user : users)
     users_.push_back(UserState{user->basic_user_info->account_id});
 
@@ -489,6 +522,25 @@ void LockContentsView::OnLockStateChanged(bool locked) {
   }
 }
 
+void LockContentsView::OnVirtualKeyboardStateChanged(
+    bool activated,
+    aura::Window* root_window) {
+  const views::Widget* widget = GetWidget();
+  if (widget) {
+    UpdateKeyboardObserverFromStateChanged(
+        activated, root_window, widget->GetNativeWindow()->GetRootWindow(),
+        &keyboard_observer_);
+  }
+}
+
+void LockContentsView::OnStateChanged(
+    const keyboard::KeyboardControllerState state) {
+  if (state == keyboard::KeyboardControllerState::SHOWN ||
+      state == keyboard::KeyboardControllerState::HIDDEN) {
+    LayoutAuth(primary_auth_, opt_secondary_auth_, false /*animate*/);
+  }
+}
+
 void LockContentsView::FocusNextWidget(bool reverse) {
   Shelf* shelf = Shelf::ForWindow(GetWidget()->GetNativeWindow());
   // Tell the focus direction to the status area or the shelf so they can focus
@@ -660,7 +712,10 @@ void LockContentsView::LayoutAuth(LoginAuthUserView* to_update,
   uint32_t to_update_auth = LoginAuthUserView::AUTH_PASSWORD;
   UserState* state =
       FindStateForUser(to_update->current_user()->basic_user_info->account_id);
-  if (state->show_pin)
+  keyboard::KeyboardController* keyboard_controller = GetKeyboardController();
+  bool keyboard_visible =
+      keyboard_controller ? keyboard_controller->keyboard_visible() : false;
+  if (state->show_pin && !keyboard_visible)
     to_update_auth |= LoginAuthUserView::AUTH_PIN;
   if (state->enable_tap_auth)
     to_update_auth |= LoginAuthUserView::AUTH_TAP;
@@ -812,6 +867,10 @@ void LockContentsView::OnEasyUnlockIconTapped() {
   }
 }
 
+keyboard::KeyboardController* LockContentsView::GetKeyboardController() const {
+  return GetWidget() ? GetKeyboardControllerForWidget(GetWidget()) : nullptr;
+}
+
 LoginAuthUserView* LockContentsView::AllocateLoginAuthUserView(
     const mojom::LoginUserInfoPtr& user,
     bool is_primary) {
