@@ -11,6 +11,7 @@
 #include "ash/login/ui/login_bubble.h"
 #include "ash/login/ui/login_display_style.h"
 #include "ash/login/ui/login_keyboard_test_base.h"
+#include "ash/login/ui/login_pin_view.h"
 #include "ash/login/ui/login_test_base.h"
 #include "ash/login/ui/login_user_view.h"
 #include "ash/login/ui/scrollable_users_list_view.h"
@@ -145,21 +146,21 @@ TEST_F(LockContentsViewUnitTest, AutoLayoutAfterRotation) {
     // Start at 0 degrees (landscape).
     display_manager()->SetDisplayRotation(
         display.id(), display::Display::ROTATE_0,
-        display::Display::ROTATION_SOURCE_ACTIVE);
+        display::Display::RotationSource::ACTIVE);
     int distance_0deg = calculate_distance();
     EXPECT_NE(distance_0deg, 0);
 
     // Rotate the display to 90 degrees (portrait).
     display_manager()->SetDisplayRotation(
         display.id(), display::Display::ROTATE_90,
-        display::Display::ROTATION_SOURCE_ACTIVE);
+        display::Display::RotationSource::ACTIVE);
     int distance_90deg = calculate_distance();
     EXPECT_GT(distance_0deg, distance_90deg);
 
     // Rotate the display back to 0 degrees (landscape).
     display_manager()->SetDisplayRotation(
         display.id(), display::Display::ROTATE_0,
-        display::Display::ROTATION_SOURCE_ACTIVE);
+        display::Display::RotationSource::ACTIVE);
     int distance_180deg = calculate_distance();
     EXPECT_EQ(distance_0deg, distance_180deg);
     EXPECT_NE(distance_0deg, distance_90deg);
@@ -185,19 +186,19 @@ TEST_F(LockContentsViewUnitTest, AutoLayoutExtraSmallUsersListAfterRotation) {
   // Start at 0 degrees (landscape).
   display_manager()->SetDisplayRotation(
       display.id(), display::Display::ROTATE_0,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(contents->height(), users_list->height());
 
   // Rotate the display to 90 degrees (portrait).
   display_manager()->SetDisplayRotation(
       display.id(), display::Display::ROTATE_90,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(contents->height(), users_list->height());
 
   // Rotate the display back to 0 degrees (landscape).
   display_manager()->SetDisplayRotation(
       display.id(), display::Display::ROTATE_0,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(contents->height(), users_list->height());
 }
 
@@ -234,21 +235,21 @@ TEST_F(LockContentsViewUnitTest, AutoLayoutSmallUsersListAfterRotation) {
   // Start at 0 degrees (landscape).
   display_manager()->SetDisplayRotation(
       display.id(), display::Display::ROTATE_0,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(top_margin(), bottom_margin());
   EXPECT_EQ(users_list->height(), users_list->contents()->height());
 
   // Rotate the display to 90 degrees (portrait).
   display_manager()->SetDisplayRotation(
       display.id(), display::Display::ROTATE_90,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(top_margin(), bottom_margin());
   EXPECT_EQ(users_list->height(), users_list->contents()->height());
 
   // Rotate the display back to 0 degrees (landscape).
   display_manager()->SetDisplayRotation(
       display.id(), display::Display::ROTATE_0,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(top_margin(), bottom_margin());
   EXPECT_EQ(users_list->height(), users_list->contents()->height());
 }
@@ -638,4 +639,30 @@ TEST_F(LockContentsViewUnitTest, EasyUnlockIconUpdatedDuringUserSwap) {
   EXPECT_FALSE(showing_easy_unlock_icon(secondary));
 }
 
+TEST_F(LockContentsViewKeyboardUnitTest, SwitchPinAndVirtualKeyboard) {
+  ASSERT_NO_FATAL_FAILURE(ShowLockScreen());
+  LockContentsView* contents =
+      LockScreen::TestApi(LockScreen::Get()).contents_view();
+  ASSERT_NE(nullptr, contents);
+
+  // Add user with enabled pin method of authentication.
+  const std::string email = "user@domain.com";
+  LoadUser(email);
+  contents->OnPinEnabledForUserChanged(AccountId::FromUserEmail(email), true);
+  LoginAuthUserView* auth_view =
+      LockContentsView::TestApi(contents).primary_auth();
+  ASSERT_NE(nullptr, auth_view);
+
+  // Pin keyboard should only be visible when there is no virtual keyboard
+  // shown.
+  LoginPinView* pin_view = LoginAuthUserView::TestApi(auth_view).pin_view();
+  EXPECT_TRUE(pin_view->visible());
+
+  ASSERT_NO_FATAL_FAILURE(ShowKeyboard());
+  EXPECT_FALSE(pin_view->visible());
+
+  ASSERT_NO_FATAL_FAILURE(HideKeyboard());
+  EXPECT_TRUE(pin_view->visible());
+}
+
 }  // namespace ash
