@@ -12,6 +12,7 @@
 #include "ash/display/root_window_transformers.h"
 #include "ash/host/ash_window_tree_host.h"
 #include "ash/host/root_window_transformer.h"
+#include "ash/magnifier/magnifier_scale_utils.h"
 #include "ash/public/cpp/ash_switches.h"
 #include "ash/public/cpp/config.h"
 #include "ash/root_window_controller.h"
@@ -94,6 +95,12 @@ ui::InputMethod* GetInputMethod(aura::Window* root_window) {
 
 namespace ash {
 
+void MagnificationController::StepToNextScaleValue(int delta_index) {
+  SetScale(magnifier_scale_utils::GetNextMagnifierScaleValue(
+               delta_index, GetScale(), kNonMagnifiedScale, kMaxMagnifiedScale),
+           true /* animate */);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // MagnificationControllerImpl:
 
@@ -138,11 +145,9 @@ class MagnificationControllerImpl : public MagnificationController,
 
   // For test
   gfx::Point GetPointOfInterestForTesting() override {
-    return point_of_interest_;
+    return point_of_interest_in_root_;
   }
 
-  void AddEventRewriterForTesting() override;
-
   bool IsOnAnimationForTesting() const override { return is_on_animation_; }
 
   void DisableMoveMagnifierDelayForTesting() override {
@@ -236,7 +241,6 @@ class MagnificationControllerImpl : public MagnificationController,
   void OnMouseEvent(ui::MouseEvent* event) override;
   void OnScrollEvent(ui::ScrollEvent* event) override;
   void OnTouchEvent(ui::TouchEvent* event) override;
-  void OnGestureEvent(ui::GestureEvent* event) override;
 
   // ui::EventRewriter overrides:
   ui::EventRewriteStatus RewriteEvent(
@@ -300,7 +304,7 @@ class MagnificationControllerImpl : public MagnificationController,
 
   // Stores the last mouse cursor (or last touched) location. This value is
   // used on zooming to keep this location visible.
-  gfx::Point point_of_interest_;
+  gfx::Point point_of_interest_in_root_;
 
   // Current scale, origin (left-top) position of the magnification window.
   float scale_;
@@ -363,13 +367,9 @@ MagnificationControllerImpl::MagnificationControllerImpl()
       disable_move_magnifier_delay_(false) {
   Shell::Get()->AddPreTargetHandler(this);
   root_window_->AddObserver(this);
+  root_window_->GetHost()->GetEventSource()->AddEventRewriter(this);
 
-  if (base::CommandLine::ForCurrentProcess()->HasSwitch(
-          ash::switches::kAshNewTouchSupportForScreenMagnification)) {
-    root_window_->GetHost()->GetEventSource()->AddEventRewriter(this);
-  }
-
-  point_of_interest_ = root_window_->bounds().CenterPoint();
+  point_of_interest_in_root_ = root_window_->bounds().CenterPoint();
 
   gesture_provider_client_ = std::make_unique<GestureProviderClient>();
   gesture_provider_ = std::make_unique<ui::GestureProviderAura>(
@@ -381,11 +381,7 @@ MagnificationControllerImpl::~MagnificationControllerImpl() {
   if (input_method)
     input_method->RemoveObserver(this);
 
-  if (base::CommandLine::ForCurrentProcess()->HasSwitch(
-          ash::switches::kAshNewTouchSupportForScreenMagnification)) {
-    root_window_->GetHost()->GetEventSource()->RemoveEventRewriter(this);
-  }
-
+  root_window_->GetHost()->GetEventSource()->RemoveEventRewriter(this);
   root_window_->RemoveObserver(this);
 
   Shell::Get()->RemovePreTargetHandler(this);
@@ -395,7 +391,7 @@ void MagnificationControllerImpl::RedrawKeepingMousePosition(
     float scale,
     bool animate,
     bool ignore_mouse_change) {
-  gfx::Point mouse_in_root = point_of_interest_;
+  gfx::Point mouse_in_root = point_of_interest_in_root_;
   // mouse_in_root is invalid value when the cursor is hidden.
   if (!root_window_->bounds().Contains(mouse_in_root))
     mouse_in_root = root_window_->bounds().CenterPoint();
@@ -570,13 +566,6 @@ void MagnificationControllerImpl::SwitchTargetRootWindow(
   root_window_->AddObserver(this);
 }
 
-void MagnificationControllerImpl::AddEventRewriterForTesting() {
-  DCHECK(base::CommandLine::ForCurrentProcess()->HasSwitch(
-      ash::switches::kAshNewTouchSupportForScreenMagnification));
-
-  root_window_->GetHost()->GetEventSource()->AddEventRewriter(this);
-}
-
 void MagnificationControllerImpl::AfterAnimationMoveCursorTo(
     const gfx::Point& location) {
   DCHECK(root_window_);
@@ -652,7 +641,7 @@ void MagnificationControllerImpl::OnWindowDestroying(
     CHECK_NE(target_root_window, root_window);
     // Don't redraw the old root window as it's being destroyed.
     SwitchTargetRootWindow(target_root_window, false);
-    point_of_interest_ = target_root_window->bounds().CenterPoint();
+    point_of_interest_in_root_ = target_root_window->bounds().CenterPoint();
   }
 }
 
@@ -754,7 +743,7 @@ void MagnificationControllerImpl::OnMouseEvent(ui::MouseEvent* event) {
   if (root_bounds.Contains(event->root_location())) {
     // This must be before |SwitchTargetRootWindow()|.
     if (event->type() != ui::ET_MOUSE_CAPTURE_CHANGED)
-      point_of_interest_ = event->root_location();
+      point_of_interest_in_root_ = event->root_location();
 
     if (current_root != root_window_) {
       DCHECK(current_root);
@@ -788,10 +777,10 @@ void MagnificationControllerImpl::OnScrollEvent(ui::ScrollEvent* event) {
     }
 
     if (event->type() == ui::ET_SCROLL) {
-      ui::ScrollEvent* scroll_event = event->AsScrollEvent();
-      SetScale(GetScaleFromScroll(scroll_event->y_offset() *
-                                  kScrollScaleChangeFactor),
-               false);
+      SetScale(magnifier_scale_utils::GetScaleFromScroll(
+                   event->y_offset() * kScrollScaleChangeFactor, GetScale(),
+                   kMaxMagnifiedScale, kNonMagnifiedScale),
+               false /* animate */);
       event->StopPropagation();
       return;
     }
@@ -801,11 +790,15 @@ void MagnificationControllerImpl::OnScrollEvent(ui::ScrollEvent* event) {
 void MagnificationControllerImpl::OnTouchEvent(ui::TouchEvent* event) {
   aura::Window* target = static_cast<aura::Window*>(event->target());
   aura::Window* current_root = target->GetRootWindow();
-  if (current_root == root_window_) {
-    gfx::Rect root_bounds = current_root->bounds();
-    if (root_bounds.Contains(event->root_location()))
-      point_of_interest_ = event->root_location();
-  }
+
+  gfx::Rect root_bounds = current_root->bounds();
+  if (!root_bounds.Contains(event->root_location()))
+    return;
+
+  point_of_interest_in_root_ = event->root_location();
+
+  if (current_root != root_window_)
+    SwitchTargetRootWindow(current_root, true);
 }
 
 ui::EventRewriteStatus MagnificationControllerImpl::RewriteEvent(
@@ -968,43 +961,6 @@ ui::EventRewriteStatus MagnificationControllerImpl::NextDispatchEvent(
   return ui::EVENT_REWRITE_REWRITTEN;
 }
 
-void MagnificationControllerImpl::OnGestureEvent(ui::GestureEvent* event) {
-  // TODO(yawano): Remove old touch support implementation once the new one is
-  // enabled by default.
-  if (base::CommandLine::ForCurrentProcess()->HasSwitch(
-          ash::switches::kAshNewTouchSupportForScreenMagnification)) {
-    return;
-  }
-
-  if (!IsEnabled())
-    return;
-
-  const ui::GestureEventDetails& details = event->details();
-  if (details.type() == ui::ET_GESTURE_SCROLL_UPDATE &&
-      details.touch_points() == 2) {
-    gfx::Rect viewport_rect_in_dip = GetViewportRect();
-    viewport_rect_in_dip.Offset(-details.scroll_x(), -details.scroll_y());
-    gfx::Rect viewport_rect_in_pixel =
-        ui::ConvertRectToPixel(root_window_->layer(), viewport_rect_in_dip);
-    MoveWindow(viewport_rect_in_pixel.origin(), false);
-    event->SetHandled();
-  } else if (details.type() == ui::ET_GESTURE_PINCH_UPDATE &&
-             details.touch_points() == 3) {
-    float scale = GetScale() * details.scale();
-    point_of_interest_ = event->root_location();
-    SetScale(scale, false);
-    event->SetHandled();
-  } else if (details.type() == ui::ET_GESTURE_PINCH_END &&
-             details.touch_points() == 3) {
-    float scale = GetScale();
-    // Jump back to exactly 1.0 if we are just a tiny bit zoomed in.
-    if (scale < kMinMagnifiedScaleThreshold) {
-      scale = kNonMagnifiedScale;
-      SetScale(scale, true);
-    }
-  }
-}
-
 void MagnificationControllerImpl::MoveMagnifierWindowFollowPoint(
     const gfx::Point& point,
     int x_panning_margin,
@@ -1178,16 +1134,4 @@ MagnificationController* MagnificationController::CreateInstance() {
   return new MagnificationControllerImpl();
 }
 
-float MagnificationController::GetScaleFromScroll(float linear_offset) {
-  float scale = GetScale();
-  const int scale_range = kMaxMagnifiedScale - kNonMagnifiedScale;
-  // Adjust the scale linearly based on the |linear_offset|
-  float linear_adjustment =
-      std::sqrt((scale - kNonMagnifiedScale) / scale_range);
-  linear_adjustment += linear_offset;
-  scale =
-      scale_range * linear_adjustment * linear_adjustment + kNonMagnifiedScale;
-  return scale;
-}
-
 }  // namespace ash
