@@ -12,6 +12,7 @@
 #include "ash/login/ui/login_test_base.h"
 #include "ash/login/ui/login_test_utils.h"
 #include "ash/public/cpp/config.h"
+#include "ash/session/test_session_controller_client.h"
 #include "ash/shell.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "base/run_loop.h"
@@ -30,7 +31,8 @@ constexpr char kNumAttemptTilSuccessHistogramName[] =
     "Ash.Login.Lock.NumPasswordAttempts.UntilSuccess";
 constexpr char kNumAttemptTilFailureHistogramName[] =
     "Ash.Login.Lock.NumPasswordAttempts.UntilFailure";
-constexpr char kUserClicksHistogramName[] = "Ash.Login.Lock.UserClicks";
+constexpr char kUserClicksOnLockHistogramName[] = "Ash.Login.Lock.UserClicks";
+constexpr char kUserClicksOnLoginHistogramName[] = "Ash.Login.Login.UserClicks";
 constexpr char kAuthMethodSwitchHistogramName[] =
     "Ash.Login.Lock.AuthMethod.Switched";
 
@@ -44,7 +46,6 @@ class LoginMetricsRecorderTest : public LoginTestBase {
   void SetUp() override {
     LoginTestBase::SetUp();
     histogram_tester_.reset(new base::HistogramTester());
-    metrics_recorder()->EnableForTesting();
   }
 
   void TearDown() override { LoginTestBase::TearDown(); }
@@ -82,6 +83,13 @@ class LoginMetricsRecorderTest : public LoginTestBase {
     histogram_tester_->ExpectBucketCount(name, static_cast<int>(target), count);
   }
 
+  void ExpectBucketCount(
+      const std::string& name,
+      LoginMetricsRecorder::LoginScreenUserClickTarget target,
+      int count) {
+    histogram_tester_->ExpectBucketCount(name, static_cast<int>(target), count);
+  }
+
   // Used to verify recorded data.
   std::unique_ptr<base::HistogramTester> histogram_tester_;
 
@@ -93,6 +101,9 @@ class LoginMetricsRecorderTest : public LoginTestBase {
 
 // Verifies that different unlock attempts get recorded in UMA.
 TEST_F(LoginMetricsRecorderTest, UnlockAttempts) {
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOCKED);
+
   std::unique_ptr<MockLoginScreenClient> client = BindMockLoginScreenClient();
   client->set_authenticate_user_callback_result(false);
   auto* contents = new LockContentsView(mojom::TrayActionState::kNotAvailable,
@@ -170,6 +181,9 @@ TEST_F(LoginMetricsRecorderTest, UnlockAttempts) {
 
 // Verifies that click on the note action button is recorded correctly.
 TEST_F(LoginMetricsRecorderTest, NoteActionButtonClick) {
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOCKED);
+
   auto* contents = new LockContentsView(mojom::TrayActionState::kAvailable,
                                         data_dispatcher());
   SetUserCount(1);
@@ -183,9 +197,9 @@ TEST_F(LoginMetricsRecorderTest, NoteActionButtonClick) {
       test_api.note_action()->GetBoundsInScreen().CenterPoint());
   generator.ClickLeftButton();
 
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 1);
   histogram_tester_->ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       static_cast<int>(LoginMetricsRecorder::LockScreenUserClickTarget::
                            kLockScreenNoteActionButton),
       1);
@@ -193,6 +207,9 @@ TEST_F(LoginMetricsRecorderTest, NoteActionButtonClick) {
 
 // Verifies that auth method usage is recorded correctly.
 TEST_F(LoginMetricsRecorderTest, AuthMethodUsage) {
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOCKED);
+
   EnableTabletMode(false);
   SetAuthMethod(LoginMetricsRecorder::AuthMethod::kPassword);
   ExpectBucketCount(kAuthMethodUsageAsClamShellHistogramName,
@@ -233,6 +250,9 @@ TEST_F(LoginMetricsRecorderTest, AuthMethodUsage) {
 
 // Verifies that auth method switching is recorded correctly.
 TEST_F(LoginMetricsRecorderTest, AuthMethodSwitch) {
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOCKED);
+
   SetAuthMethod(LoginMetricsRecorder::AuthMethod::kPassword);
   histogram_tester_->ExpectTotalCount(kAuthMethodSwitchHistogramName, 0);
 
@@ -275,6 +295,9 @@ TEST_F(LoginMetricsRecorderTest, AuthMethodSwitch) {
 
 // Verifies that number of auth attempts are recorded correctly.
 TEST_F(LoginMetricsRecorderTest, RecordNumLoginAttempts) {
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOCKED);
+
   metrics_recorder()->RecordNumLoginAttempts(5, true /*success*/);
   histogram_tester_->ExpectTotalCount(kNumAttemptTilSuccessHistogramName, 1);
   histogram_tester_->ExpectBucketCount(kNumAttemptTilSuccessHistogramName, 5,
@@ -291,71 +314,151 @@ TEST_F(LoginMetricsRecorderTest, RecordNumLoginAttempts) {
 
 // Verifies that user click events on the lock screen is recorded correctly.
 TEST_F(LoginMetricsRecorderTest, RecordUserClickEventOnLockScreen) {
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 0);
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kShutDownButton);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 1);
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOCKED);
+
+  // Clicks on shelf buttons visible during lock should be recorded.
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kShutDownButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 1);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kShutDownButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kRestartButton);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 2);
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kRestartButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 2);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kRestartButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kSignOutButton);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 3);
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kSignOutButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 3);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kSignOutButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kCloseNoteButton);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 4);
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kCloseNoteButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 4);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kCloseNoteButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kSystemTray);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 5);
+  // Clicks on tray elements visible during lock should be recorded.
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kSystemTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 5);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kSystemTray, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kVirtualKeyboardTray);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 6);
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kVirtualKeyboardTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 6);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kVirtualKeyboardTray, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kImeTray);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 7);
-  ExpectBucketCount(kUserClicksHistogramName,
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kImeTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 7);
+  ExpectBucketCount(kUserClicksOnLockHistogramName,
                     LoginMetricsRecorder::LockScreenUserClickTarget::kImeTray,
                     1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::kNotificationTray);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 8);
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kNotificationTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 8);
   ExpectBucketCount(
-      kUserClicksHistogramName,
+      kUserClicksOnLockHistogramName,
       LoginMetricsRecorder::LockScreenUserClickTarget::kNotificationTray, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
 
-  metrics_recorder()->RecordUserClickEventOnLockScreen(
-      LoginMetricsRecorder::LockScreenUserClickTarget::
-          kLockScreenNoteActionButton);
-  histogram_tester_->ExpectTotalCount(kUserClicksHistogramName, 9);
-  ExpectBucketCount(kUserClicksHistogramName,
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kTrayActionNoteButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 9);
+  ExpectBucketCount(kUserClicksOnLockHistogramName,
                     LoginMetricsRecorder::LockScreenUserClickTarget::
                         kLockScreenNoteActionButton,
                     1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
+}
+
+// Verifies that user click events on the login screen is recorded correctly.
+TEST_F(LoginMetricsRecorderTest, RecordUserClickEventOnLoginScreen) {
+  GetSessionControllerClient()->SetSessionState(
+      session_manager::SessionState::LOGIN_PRIMARY);
+
+  // Clicks on shelf buttons visible during login should be recorded.
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 0);
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kShutDownButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 1);
+  ExpectBucketCount(
+      kUserClicksOnLoginHistogramName,
+      LoginMetricsRecorder::LoginScreenUserClickTarget::kShutDownButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kRestartButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 2);
+  ExpectBucketCount(
+      kUserClicksOnLoginHistogramName,
+      LoginMetricsRecorder::LoginScreenUserClickTarget::kRestartButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kBrowseAsGuestButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 3);
+  ExpectBucketCount(
+      kUserClicksOnLoginHistogramName,
+      LoginMetricsRecorder::LoginScreenUserClickTarget::kBrowseAsGuestButton,
+      1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+
+  metrics_recorder()->RecordUserShelfButtonClick(
+      LoginMetricsRecorder::ShelfButtonClickTarget::kAddUserButton);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 4);
+  ExpectBucketCount(
+      kUserClicksOnLoginHistogramName,
+      LoginMetricsRecorder::LoginScreenUserClickTarget::kAddUserButton, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+
+  // Clicks on tray elements visible during login should be recorded.
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kSystemTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 5);
+  ExpectBucketCount(
+      kUserClicksOnLoginHistogramName,
+      LoginMetricsRecorder::LoginScreenUserClickTarget::kSystemTray, 1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kVirtualKeyboardTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 6);
+  ExpectBucketCount(
+      kUserClicksOnLoginHistogramName,
+      LoginMetricsRecorder::LoginScreenUserClickTarget::kVirtualKeyboardTray,
+      1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
+
+  metrics_recorder()->RecordUserTrayClick(
+      LoginMetricsRecorder::TrayClickTarget::kImeTray);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLoginHistogramName, 7);
+  ExpectBucketCount(kUserClicksOnLoginHistogramName,
+                    LoginMetricsRecorder::LoginScreenUserClickTarget::kImeTray,
+                    1);
+  histogram_tester_->ExpectTotalCount(kUserClicksOnLockHistogramName, 0);
 }
 
 }  // namespace ash
