@@ -82,6 +82,7 @@ class AcceleratorController;
 class AccessibilityController;
 class AccessibilityDelegate;
 class AshDisplayController;
+class AppListControllerImpl;
 class AppListDelegateImpl;
 class NativeCursorManagerAsh;
 class AshTouchTransformController;
@@ -91,10 +92,12 @@ class BluetoothNotificationController;
 class BluetoothPowerController;
 class BrightnessControlDelegate;
 class CastConfigController;
+class DetachableBaseHandler;
 class DisplayColorManager;
 class DisplayConfigurationController;
 class DisplayErrorObserver;
 class DisplayShutdownObserver;
+class DockedMagnifierController;
 class DragDropController;
 class EventClientImpl;
 class EventTransformationHandler;
@@ -124,6 +127,7 @@ class NoteTakingController;
 class OverlayEventFilter;
 class PartialMagnificationController;
 class PeripheralBatteryNotifier;
+class PersistentWindowController;
 class PowerButtonController;
 class PowerEventObserver;
 class ProjectingObserver;
@@ -151,6 +155,7 @@ class SystemGestureEventFilter;
 class SystemModalContainerEventFilter;
 class SystemTray;
 class SystemTrayController;
+class SystemTrayModel;
 class SystemTrayNotifier;
 class TimeToFirstPresentRecorder;
 class ToplevelWindowEventHandler;
@@ -164,7 +169,6 @@ class VideoDetector;
 class VoiceInteractionController;
 class VpnList;
 class WallpaperController;
-class WallpaperDelegate;
 class WebNotificationTray;
 class WindowCycleController;
 class WindowPositioner;
@@ -309,6 +313,9 @@ class ASH_EXPORT Shell : public SessionObserver,
   }
   ::wm::ActivationClient* activation_client();
   app_list::AppList* app_list() { return app_list_.get(); }
+  AppListControllerImpl* app_list_controller() {
+    return app_list_controller_.get();
+  }
   AshDisplayController* ash_display_controller() {
     return ash_display_controller_.get();
   }
@@ -329,6 +336,10 @@ class ASH_EXPORT Shell : public SessionObserver,
   // Returns nullptr in mash which has no global cursor manager.
   ::wm::CursorManager* cursor_manager() { return cursor_manager_.get(); }
 
+  DetachableBaseHandler* detachable_base_handler() {
+    return detachable_base_handler_.get();
+  }
+
   display::DisplayManager* display_manager() { return display_manager_.get(); }
   DisplayConfigurationController* display_configuration_controller() {
     return display_configuration_controller_.get();
@@ -342,6 +353,7 @@ class ASH_EXPORT Shell : public SessionObserver,
     return display_error_observer_.get();
   }
 
+  DockedMagnifierController* docked_magnifier_controller();
   ::wm::CompoundEventFilter* env_filter() { return env_filter_.get(); }
   EventClientImpl* event_client() { return event_client_.get(); }
   EventTransformationHandler* event_transformation_handler() {
@@ -436,6 +448,7 @@ class ASH_EXPORT Shell : public SessionObserver,
   SystemTrayController* system_tray_controller() {
     return system_tray_controller_.get();
   }
+  SystemTrayModel* system_tray_model() { return system_tray_model_.get(); }
   SystemTrayNotifier* system_tray_notifier() {
     return system_tray_notifier_.get();
   }
@@ -471,7 +484,6 @@ class ASH_EXPORT Shell : public SessionObserver,
   WallpaperController* wallpaper_controller() {
     return wallpaper_controller_.get();
   }
-  WallpaperDelegate* wallpaper_delegate() { return wallpaper_delegate_.get(); }
   WindowCycleController* window_cycle_controller() {
     return window_cycle_controller_.get();
   }
@@ -539,6 +551,10 @@ class ASH_EXPORT Shell : public SessionObserver,
   // windows get re-arranged).
   void NotifyOverviewModeStarting();
 
+  // Notifies observers that overview mode is about to end (bofore the windows
+  // restore themselves).
+  void NotifyOverviewModeEnding();
+
   // Notifies observers that overview mode has ended.
   void NotifyOverviewModeEnded();
 
@@ -645,10 +661,12 @@ class ASH_EXPORT Shell : public SessionObserver,
   std::unique_ptr<AcceleratorController> accelerator_controller_;
   std::unique_ptr<AccessibilityController> accessibility_controller_;
   std::unique_ptr<AccessibilityDelegate> accessibility_delegate_;
+  std::unique_ptr<AppListControllerImpl> app_list_controller_;
   std::unique_ptr<AshDisplayController> ash_display_controller_;
   std::unique_ptr<BacklightsForcedOffSetter> backlights_forced_off_setter_;
   std::unique_ptr<BrightnessControlDelegate> brightness_control_delegate_;
   std::unique_ptr<CastConfigController> cast_config_;
+  std::unique_ptr<DetachableBaseHandler> detachable_base_handler_;
   std::unique_ptr<DragDropController> drag_drop_controller_;
   std::unique_ptr<FocusCycler> focus_cycler_;
   std::unique_ptr<ImeController> ime_controller_;
@@ -672,6 +690,7 @@ class ASH_EXPORT Shell : public SessionObserver,
   std::unique_ptr<ShellDelegate> shell_delegate_;
   std::unique_ptr<ShutdownController> shutdown_controller_;
   std::unique_ptr<SystemTrayController> system_tray_controller_;
+  std::unique_ptr<SystemTrayModel> system_tray_model_;
   std::unique_ptr<SystemTrayNotifier> system_tray_notifier_;
   std::unique_ptr<ToastManager> toast_manager_;
   std::unique_ptr<TouchDevicesController> touch_devices_controller_;
@@ -680,7 +699,6 @@ class ASH_EXPORT Shell : public SessionObserver,
   std::unique_ptr<VoiceInteractionController> voice_interaction_controller_;
   std::unique_ptr<VpnList> vpn_list_;
   std::unique_ptr<WallpaperController> wallpaper_controller_;
-  std::unique_ptr<WallpaperDelegate> wallpaper_delegate_;
   std::unique_ptr<WindowCycleController> window_cycle_controller_;
   std::unique_ptr<WindowSelectorController> window_selector_controller_;
   std::unique_ptr<::wm::ShadowController> shadow_controller_;
@@ -694,6 +712,7 @@ class ASH_EXPORT Shell : public SessionObserver,
   std::unique_ptr<ui::UserActivityDetector> user_activity_detector_;
   std::unique_ptr<VideoDetector> video_detector_;
   std::unique_ptr<WindowTreeHostManager> window_tree_host_manager_;
+  std::unique_ptr<PersistentWindowController> persistent_window_controller_;
   std::unique_ptr<HighContrastController> high_contrast_controller_;
   std::unique_ptr<MagnificationController> magnification_controller_;
   std::unique_ptr<AutoclickController> autoclick_controller_;
@@ -770,6 +789,8 @@ class ASH_EXPORT Shell : public SessionObserver,
       partial_magnification_controller_;
   std::unique_ptr<HighlighterController> highlighter_controller_;
 
+  std::unique_ptr<DockedMagnifierController> docked_magnifier_controller_;
+
   // The split view controller for Chrome OS in tablet mode.
   std::unique_ptr<SplitViewController> split_view_controller_;
 
