@@ -51,6 +51,7 @@ class ScreenLayoutObserverTest : public AshTestBase {
   void CheckUpdate();
 
   void CloseNotification();
+  void ClickNotification();
   base::string16 GetDisplayNotificationText() const;
   base::string16 GetDisplayNotificationAdditionalText() const;
 
@@ -82,6 +83,11 @@ void ScreenLayoutObserverTest::CloseNotification() {
   RunAllPendingInMessageLoop();
 }
 
+void ScreenLayoutObserverTest::ClickNotification() {
+  const message_center::Notification* notification = GetDisplayNotification();
+  notification->Click();
+}
+
 base::string16 ScreenLayoutObserverTest::GetDisplayNotificationText() const {
   const message_center::Notification* notification = GetDisplayNotification();
   return notification ? notification->title() : base::string16();
@@ -587,14 +593,14 @@ TEST_F(ScreenLayoutObserverTest, RotationNotification) {
   // The accelerometer source.
   display_manager()->SetDisplayRotation(
       primary_id, display::Display::ROTATE_90,
-      display::Display::ROTATION_SOURCE_ACCELEROMETER);
+      display::Display::RotationSource::ACCELEROMETER);
   EXPECT_TRUE(GetDisplayNotificationText().empty());
   EXPECT_TRUE(GetDisplayNotificationAdditionalText().empty());
 
   // The user source.
   display_manager()->SetDisplayRotation(primary_id,
                                         display::Display::ROTATE_180,
-                                        display::Display::ROTATION_SOURCE_USER);
+                                        display::Display::RotationSource::USER);
   EXPECT_EQ(l10n_util::GetStringFUTF16(
                 IDS_ASH_STATUS_TRAY_DISPLAY_ROTATED, GetFirstDisplayName(),
                 l10n_util::GetStringUTF16(
@@ -604,7 +610,7 @@ TEST_F(ScreenLayoutObserverTest, RotationNotification) {
   // The active source.
   display_manager()->SetDisplayRotation(
       primary_id, display::Display::ROTATE_270,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_EQ(l10n_util::GetStringFUTF16(
                 IDS_ASH_STATUS_TRAY_DISPLAY_ROTATED, GetFirstDisplayName(),
                 l10n_util::GetStringUTF16(
@@ -617,13 +623,13 @@ TEST_F(ScreenLayoutObserverTest, RotationNotification) {
   // The accelerometer source.
   display_manager()->SetDisplayRotation(
       primary_id, display::Display::ROTATE_90,
-      display::Display::ROTATION_SOURCE_ACCELEROMETER);
+      display::Display::RotationSource::ACCELEROMETER);
   EXPECT_TRUE(GetDisplayNotificationText().empty());
 
   // The user source.
   display_manager()->SetDisplayRotation(primary_id,
                                         display::Display::ROTATE_180,
-                                        display::Display::ROTATION_SOURCE_USER);
+                                        display::Display::RotationSource::USER);
   EXPECT_EQ(l10n_util::GetStringFUTF16(
                 IDS_ASH_STATUS_TRAY_DISPLAY_ROTATED, GetFirstDisplayName(),
                 l10n_util::GetStringUTF16(
@@ -633,7 +639,7 @@ TEST_F(ScreenLayoutObserverTest, RotationNotification) {
   // The active source.
   display_manager()->SetDisplayRotation(
       primary_id, display::Display::ROTATE_270,
-      display::Display::ROTATION_SOURCE_ACTIVE);
+      display::Display::RotationSource::ACTIVE);
   EXPECT_TRUE(GetDisplayNotificationText().empty());
 }
 
@@ -706,4 +712,17 @@ TEST_F(ScreenLayoutObserverTest, MirrorModeAddOrRemoveDisplayMessage) {
   EXPECT_TRUE(display_manager()->IsInMirrorMode());
 }
 
+TEST_F(ScreenLayoutObserverTest, ClickNotification) {
+  Shell::Get()->screen_layout_observer()->set_show_notifications_for_testing(
+      true);
+
+  // Create notification.
+  UpdateDisplay("400x400/r");
+  EXPECT_FALSE(GetDisplayNotificationAdditionalText().empty());
+
+  // Click notification.
+  ClickNotification();
+  EXPECT_TRUE(GetDisplayNotificationAdditionalText().empty());
+}
+
 }  // namespace ash
