@@ -6,10 +6,12 @@
 
 #include <memory>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "ash/accelerators/accelerator_controller.h"
-#include "ash/accessibility/accessibility_delegate.h"
+#include "ash/accessibility/accessibility_controller.h"
+#include "ash/app_list/test/app_list_test_helper.h"
 #include "ash/ash_view_ids.h"
 #include "ash/public/cpp/shell_window_ids.h"
 #include "ash/root_window_controller.h"
@@ -31,9 +33,8 @@
 #include "ash/wm/window_util.h"
 #include "base/memory/ptr_util.h"
 #include "base/run_loop.h"
+#include "base/stl_util.h"
 #include "base/test/histogram_tester.h"
-#include "ui/app_list/presenter/app_list.h"
-#include "ui/app_list/presenter/test/test_app_list_presenter.h"
 #include "ui/base/ui_base_types.h"
 #include "ui/compositor/scoped_animation_duration_scale_mode.h"
 #include "ui/events/test/event_generator.h"
@@ -96,7 +97,7 @@ class SystemTrayTest : public AshTestBase {
 
   // Swiping on the system tray and ends with finger released. Note, |start| is
   // based on the system tray or system tray bubble's coordinate space.
-  void SendGestureEvent(gfx::Point& start,
+  void SendGestureEvent(const gfx::Point& start,
                         float delta,
                         bool is_fling,
                         float velocity_y,
@@ -116,7 +117,7 @@ class SystemTrayTest : public AshTestBase {
   }
 
   // Swiping on the system tray without releasing the finger.
-  void SendScrollStartAndUpdate(gfx::Point& start,
+  void SendScrollStartAndUpdate(const gfx::Point& start,
                                 float delta,
                                 base::TimeTicks& timestamp,
                                 float scroll_y_hint = -1.0f,
@@ -425,24 +426,20 @@ TEST_F(SystemTrayTest, ToggleAppListAfterOpenSystemTrayBubbleInTabletMode) {
   ASSERT_FALSE(system_tray->drag_controller());
   EXPECT_FALSE(system_tray->clipping_window_for_test());
 
-  app_list::test::TestAppListPresenter test_app_list_presenter;
-  Shell::Get()->app_list()->SetAppListPresenter(
-      test_app_list_presenter.CreateInterfacePtrAndBind());
-
   // Convert from tablet mode to clamshell.
   Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(false);
-  EXPECT_EQ(0u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->CheckVisibility(false);
 
   // Press the search key should toggle the launcher.
   ui::test::EventGenerator& generator = GetEventGenerator();
   generator.PressKey(ui::VKEY_BROWSER_SEARCH, ui::EF_NONE);
-  RunAllPendingInMessageLoop();
-  EXPECT_EQ(1u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->WaitUntilIdle();
+  GetAppListTestHelper()->CheckVisibility(true);
 
   // Press the search key again should still toggle the launcher.
   generator.PressKey(ui::VKEY_BROWSER_SEARCH, ui::EF_NONE);
-  RunAllPendingInMessageLoop();
-  EXPECT_EQ(2u, test_app_list_presenter.toggle_count());
+  GetAppListTestHelper()->WaitUntilIdle();
+  GetAppListTestHelper()->CheckVisibility(false);
 }
 
 // Verifies only the visible default views are recorded in the
@@ -714,9 +711,8 @@ TEST_F(SystemTrayTest, SystemTrayTestItems) {
 
   // Check items have been added.
   std::vector<SystemTrayItem*> items = tray->GetTrayItems();
-  ASSERT_TRUE(std::find(items.begin(), items.end(), test_item) != items.end());
-  ASSERT_TRUE(std::find(items.begin(), items.end(), detailed_item) !=
-              items.end());
+  ASSERT_TRUE(base::ContainsValue(items, test_item));
+  ASSERT_TRUE(base::ContainsValue(items, detailed_item));
 
   // Ensure the tray views are created.
   ASSERT_TRUE(test_item->tray_view() != NULL);
@@ -913,7 +909,7 @@ TEST_F(SystemTrayTest, PersistentBubble) {
 // status.
 TEST_F(SystemTrayTest, WithSystemModal) {
   // The accessiblity item is created and is visible either way.
-  Shell::Get()->accessibility_delegate()->SetVirtualKeyboardEnabled(true);
+  Shell::Get()->accessibility_controller()->SetVirtualKeyboardEnabled(true);
   std::unique_ptr<views::Widget> widget(CreateTestWidget(
       new ModalWidgetDelegate, kShellWindowId_SystemModalContainer,
       gfx::Rect(0, 0, 100, 100)));
