@@ -21,7 +21,6 @@
 #include "ash/shell_delegate.h"
 #include "ash/wallpaper/wallpaper_controller_observer.h"
 #include "ash/wallpaper/wallpaper_decoder.h"
-#include "ash/wallpaper/wallpaper_delegate.h"
 #include "ash/wallpaper/wallpaper_view.h"
 #include "ash/wallpaper/wallpaper_widget_controller.h"
 #include "base/bind.h"
@@ -423,17 +422,6 @@ base::FilePath WallpaperController::GetCustomWallpaperDir(
   return dir_chrome_os_custom_wallpapers_path_.Append(sub_dir);
 }
 
-// static
-base::FilePath WallpaperController::GetDeviceWallpaperDir() {
-  DCHECK(!dir_chrome_os_wallpapers_path_.empty());
-  return dir_chrome_os_wallpapers_path_.Append(kDeviceWallpaperDir);
-}
-
-// static
-base::FilePath WallpaperController::GetDeviceWallpaperFilePath() {
-  return GetDeviceWallpaperDir().Append(kDeviceWallpaperFile);
-}
-
 // static
 bool WallpaperController::ResizeImage(
     const gfx::ImageSkia& image,
@@ -510,6 +498,13 @@ bool WallpaperController::ResizeAndSaveWallpaper(
   return false;
 }
 
+// static
+base::FilePath WallpaperController::GetDevicePolicyWallpaperFilePath() {
+  DCHECK(!dir_chrome_os_wallpapers_path_.empty());
+  return dir_chrome_os_wallpapers_path_.Append(kDeviceWallpaperDir)
+      .Append(kDeviceWallpaperFile);
+}
+
 // static
 void WallpaperController::SetWallpaperFromPath(
     const AccountId& account_id,
@@ -588,13 +583,6 @@ bool WallpaperController::WriteJPEGFileForTesting(const base::FilePath& path,
   return true;
 }
 
-// static
-base::FilePath WallpaperController::GetDevicePolicyWallpaperFilePath() {
-  DCHECK(!dir_chrome_os_wallpapers_path_.empty());
-  return dir_chrome_os_wallpapers_path_.Append(kDeviceWallpaperDir)
-      .Append(kDeviceWallpaperFile);
-}
-
 void WallpaperController::BindRequest(
     mojom::WallpaperControllerRequest request) {
   bindings_.AddBinding(this, std::move(request));
@@ -639,6 +627,35 @@ wallpaper::WallpaperType WallpaperController::GetWallpaperType() const {
   return wallpaper::WALLPAPER_TYPE_COUNT;
 }
 
+bool WallpaperController::ShouldShowInitialAnimation() {
+  // The slower initial animation is only applicable if:
+  // 1) It's the first run after system boot, not after user sign-out.
+  if (!base::CommandLine::ForCurrentProcess()->HasSwitch(
+          chromeos::switches::kFirstExecAfterBoot)) {
+    return false;
+  }
+  // 2) It's at the login screen.
+  if (Shell::Get()->session_controller()->IsActiveUserSessionStarted() ||
+      !base::CommandLine::ForCurrentProcess()->HasSwitch(
+          chromeos::switches::kLoginManager)) {
+    return false;
+  }
+  // 3) It's the first wallpaper being shown, not for the switching between
+  //    multiple user pods.
+  if (!is_first_wallpaper_)
+    return false;
+
+  return true;
+}
+
+void WallpaperController::OnWallpaperAnimationFinished() {
+  // TODO(crbug.com/784495, 776464): This is used by a code path in web-UI
+  // login. Remove it if views-based login is not interested in this event.
+  if (wallpaper_controller_client_ && is_first_wallpaper_) {
+    wallpaper_controller_client_->OnFirstWallpaperAnimationFinished();
+  }
+}
+
 void WallpaperController::SetDefaultWallpaperImpl(
     const AccountId& account_id,
     const user_manager::UserType& user_type,
@@ -674,10 +691,10 @@ void WallpaperController::SetDefaultWallpaperImpl(
         use_small ? chromeos::switches::kChildWallpaperSmall
                   : chromeos::switches::kChildWallpaperLarge;
     file_path = command_line->GetSwitchValuePath(switch_string);
-  } else if (!customized_default_wallpaper_small_.empty()) {
-    DCHECK(!customized_default_wallpaper_large_.empty());
-    file_path = use_small ? customized_default_wallpaper_small_
-                          : customized_default_wallpaper_large_;
+  } else if (!customized_default_small_path_.empty()) {
+    DCHECK(!customized_default_large_path_.empty());
+    file_path = use_small ? customized_default_small_path_
+                          : customized_default_large_path_;
   } else {
     const std::string switch_string =
         use_small ? chromeos::switches::kDefaultWallpaperSmall
@@ -701,27 +718,6 @@ void WallpaperController::SetDefaultWallpaperImpl(
   }
 }
 
-void WallpaperController::SetCustomizedDefaultWallpaperPaths(
-    const base::FilePath& customized_default_wallpaper_file_small,
-    const base::FilePath& customized_default_wallpaper_file_large) {
-  customized_default_wallpaper_small_ = customized_default_wallpaper_file_small;
-  customized_default_wallpaper_large_ = customized_default_wallpaper_file_large;
-
-  // If the current wallpaper is the default one, then the new customized
-  // default wallpaper should be shown immediately to update the screen. It
-  // shouldn't replace wallpapers of other types.
-  bool show_wallpaper = true;
-  if (current_wallpaper_ && GetWallpaperType() != wallpaper::DEFAULT)
-    show_wallpaper = false;
-
-  // Customized default wallpapers are subject to the same restrictions as other
-  // default wallpapers, e.g. they should not be set during guest sessions.
-  // TODO(crbug.com/776464): Find a way to directly set wallpaper from here, or
-  // combine this method with |SetDefaultWallpaperImpl|.
-  SetDefaultWallpaperImpl(EmptyAccountId(), user_manager::USER_TYPE_REGULAR,
-                          show_wallpaper);
-}
-
 bool WallpaperController::CanOpenWallpaperPicker() {
   return ShouldShowWallpaperSettingImpl() &&
          !IsActiveUserWallpaperControlledByPolicyImpl();
@@ -751,6 +747,8 @@ void WallpaperController::SetWallpaperImage(const gfx::ImageSkia& image,
     color_calculator_->RemoveObserver(this);
     color_calculator_.reset();
   }
+
+  is_first_wallpaper_ = !current_wallpaper_;
   current_wallpaper_.reset(new wallpaper::WallpaperResizer(
       image, GetMaxDisplaySizeInNative(), info, sequenced_task_runner_));
   current_wallpaper_->AddObserver(this);
@@ -758,34 +756,27 @@ void WallpaperController::SetWallpaperImage(const gfx::ImageSkia& image,
 
   for (auto& observer : observers_)
     observer.OnWallpaperDataChanged();
+
   wallpaper_mode_ = WALLPAPER_IMAGE;
   InstallDesktopControllerForAllWindows();
   wallpaper_count_for_testing_++;
 }
 
-void WallpaperController::CreateEmptyWallpaper() {
-  SetProminentColors(
-      std::vector<SkColor>(color_profiles_.size(), kInvalidColor));
-  current_wallpaper_.reset();
-  wallpaper_mode_ = WALLPAPER_IMAGE;
-  InstallDesktopControllerForAllWindows();
-}
-
 bool WallpaperController::IsPolicyControlled(const AccountId& account_id,
-                                             bool is_persistent) const {
+                                             bool is_ephemeral) const {
   WallpaperInfo info;
-  if (!GetUserWallpaperInfo(account_id, &info, is_persistent))
+  if (!GetUserWallpaperInfo(account_id, &info, is_ephemeral))
     return false;
   return info.type == wallpaper::POLICY;
 }
 
 bool WallpaperController::CanSetUserWallpaper(const AccountId& account_id,
-                                              bool is_persistent) const {
+                                              bool is_ephemeral) const {
   // There is no visible wallpaper in kiosk mode.
   if (IsInKioskMode())
     return false;
   // Don't allow user wallpapers while policy is in effect.
-  if (IsPolicyControlled(account_id, is_persistent)) {
+  if (IsPolicyControlled(account_id, is_ephemeral)) {
     return false;
   }
   return true;
@@ -795,13 +786,9 @@ void WallpaperController::PrepareWallpaperForLockScreenChange(bool locking) {
   bool needs_blur = locking && IsBlurEnabled();
   if (needs_blur != is_wallpaper_blurred_) {
     for (auto* root_window_controller : Shell::GetAllRootWindowControllers()) {
-      WallpaperWidgetController* wallpaper_widget_controller =
-          root_window_controller->wallpaper_widget_controller();
-      if (wallpaper_widget_controller) {
-        wallpaper_widget_controller->SetWallpaperBlur(
-            needs_blur ? login_constants::kBlurSigma
-                       : login_constants::kClearBlurSigma);
-      }
+      root_window_controller->wallpaper_widget_controller()->SetWallpaperBlur(
+          needs_blur ? login_constants::kBlurSigma
+                     : login_constants::kClearBlurSigma);
     }
     is_wallpaper_blurred_ = needs_blur;
     // TODO(crbug.com/776464): Replace the observer with mojo calls so that
@@ -820,7 +807,7 @@ std::string WallpaperController::GetActiveUserWallpaperLocation() {
 
   WallpaperInfo info;
   if (!GetUserWallpaperInfo(active_user_session->user_info->account_id, &info,
-                            !active_user_session->user_info->is_ephemeral)) {
+                            active_user_session->user_info->is_ephemeral)) {
     return std::string();
   }
   return info.location;
@@ -859,7 +846,12 @@ void WallpaperController::OnRootWindowAdded(aura::Window* root_window) {
 
 void WallpaperController::OnLocalStatePrefServiceInitialized(
     PrefService* pref_service) {
-  Shell::Get()->wallpaper_delegate()->InitializeWallpaper();
+  if (wallpaper_controller_client_) {
+    wallpaper_controller_client_->OnReadyToSetWallpaper();
+  } else {
+    // Ensure unit tests have a wallpaper as placeholder.
+    CreateEmptyWallpaperForTesting();
+  }
 }
 
 void WallpaperController::OnSessionStateChanged(
@@ -935,8 +927,8 @@ bool WallpaperController::IsBlurEnabled() const {
 
 void WallpaperController::SetUserWallpaperInfo(const AccountId& account_id,
                                                const WallpaperInfo& info,
-                                               bool is_persistent) {
-  if (!is_persistent) {
+                                               bool is_ephemeral) {
+  if (is_ephemeral) {
     ephemeral_users_wallpaper_info_[account_id] = info;
     return;
   }
@@ -946,7 +938,7 @@ void WallpaperController::SetUserWallpaperInfo(const AccountId& account_id,
   if (!local_state)
     return;
   WallpaperInfo old_info;
-  if (GetUserWallpaperInfo(account_id, &old_info, is_persistent)) {
+  if (GetUserWallpaperInfo(account_id, &old_info, is_ephemeral)) {
     // Remove the color cache of the previous wallpaper if it exists.
     DictionaryPrefUpdate wallpaper_colors_update(local_state,
                                                  prefs::kWallpaperColors);
@@ -968,8 +960,8 @@ void WallpaperController::SetUserWallpaperInfo(const AccountId& account_id,
 
 bool WallpaperController::GetUserWallpaperInfo(const AccountId& account_id,
                                                WallpaperInfo* info,
-                                               bool is_persistent) const {
-  if (!is_persistent) {
+                                               bool is_ephemeral) const {
+  if (is_ephemeral) {
     // Ephemeral users do not save anything to local state. Return true if the
     // info can be found in the map, otherwise return false.
     auto it = ephemeral_users_wallpaper_info_.find(account_id);
@@ -1017,11 +1009,11 @@ bool WallpaperController::GetUserWallpaperInfo(const AccountId& account_id,
 
 void WallpaperController::InitializeUserWallpaperInfo(
     const AccountId& account_id,
-    bool is_persistent) {
+    bool is_ephemeral) {
   const wallpaper::WallpaperInfo info = {
       std::string(), wallpaper::WALLPAPER_LAYOUT_CENTER_CROPPED,
       wallpaper::DEFAULT, base::Time::Now().LocalMidnight()};
-  SetUserWallpaperInfo(account_id, info, is_persistent);
+  SetUserWallpaperInfo(account_id, info, is_ephemeral);
 }
 
 void WallpaperController::SetArcWallpaper(
@@ -1033,7 +1025,7 @@ void WallpaperController::SetArcWallpaper(
     wallpaper::WallpaperLayout layout,
     bool is_ephemeral,
     bool show_wallpaper) {
-  if (!CanSetUserWallpaper(account_id, !is_ephemeral))
+  if (!CanSetUserWallpaper(account_id, is_ephemeral))
     return;
 
   ash::mojom::WallpaperUserInfoPtr user_info =
@@ -1093,7 +1085,7 @@ void WallpaperController::Init(
   dir_user_data_path_ = user_data_path;
   dir_chrome_os_wallpapers_path_ = chromeos_wallpapers_path;
   dir_chrome_os_custom_wallpapers_path_ = chromeos_custom_wallpapers_path;
-  SetDeviceWallpaperPolicyEnforced(is_device_wallpaper_policy_enforced);
+  is_device_wallpaper_policy_enforced_ = is_device_wallpaper_policy_enforced;
 }
 
 void WallpaperController::SetCustomWallpaper(
@@ -1103,7 +1095,7 @@ void WallpaperController::SetCustomWallpaper(
     wallpaper::WallpaperLayout layout,
     const SkBitmap& image,
     bool show_wallpaper) {
-  if (!CanSetUserWallpaper(user_info->account_id, !user_info->is_ephemeral))
+  if (!CanSetUserWallpaper(user_info->account_id, user_info->is_ephemeral))
     return;
   SaveAndSetWallpaper(std::move(user_info), wallpaper_files_id, file_name,
                       wallpaper::CUSTOMIZED, layout, show_wallpaper,
@@ -1118,7 +1110,7 @@ void WallpaperController::SetOnlineWallpaper(
     bool show_wallpaper) {
   DCHECK(Shell::Get()->session_controller()->IsActiveUserSessionStarted());
 
-  if (!CanSetUserWallpaper(user_info->account_id, !user_info->is_ephemeral))
+  if (!CanSetUserWallpaper(user_info->account_id, user_info->is_ephemeral))
     return;
 
   gfx::ImageSkia online_wallpaper = gfx::ImageSkia::CreateFrom1xBitmap(image);
@@ -1130,7 +1122,7 @@ void WallpaperController::SetOnlineWallpaper(
 
   WallpaperInfo info = {url, layout, wallpaper::ONLINE,
                         base::Time::Now().LocalMidnight()};
-  SetUserWallpaperInfo(user_info->account_id, info, !user_info->is_ephemeral);
+  SetUserWallpaperInfo(user_info->account_id, info, user_info->is_ephemeral);
   if (show_wallpaper)
     SetWallpaperImage(online_wallpaper, info);
 
@@ -1145,25 +1137,37 @@ void WallpaperController::SetDefaultWallpaper(
     mojom::WallpaperUserInfoPtr user_info,
     const std::string& wallpaper_files_id,
     bool show_wallpaper) {
-  if (!CanSetUserWallpaper(user_info->account_id, !user_info->is_ephemeral))
+  if (!CanSetUserWallpaper(user_info->account_id, user_info->is_ephemeral))
     return;
 
   const AccountId account_id = user_info->account_id;
-  const bool is_persistent = !user_info->is_ephemeral;
+  const bool is_ephemeral = user_info->is_ephemeral;
   const user_manager::UserType type = user_info->type;
 
   RemoveUserWallpaper(std::move(user_info), wallpaper_files_id);
-  InitializeUserWallpaperInfo(account_id, is_persistent);
+  InitializeUserWallpaperInfo(account_id, is_ephemeral);
   if (show_wallpaper) {
     SetDefaultWallpaperImpl(account_id, type, true /*show_wallpaper=*/);
   }
 }
 
-void WallpaperController::SetCustomizedDefaultWallpaper(
-    const GURL& wallpaper_url,
-    const base::FilePath& file_path,
-    const base::FilePath& resized_directory) {
-  NOTIMPLEMENTED();
+void WallpaperController::SetCustomizedDefaultWallpaperPaths(
+    const base::FilePath& customized_default_small_path,
+    const base::FilePath& customized_default_large_path) {
+  customized_default_small_path_ = customized_default_small_path;
+  customized_default_large_path_ = customized_default_large_path;
+
+  // If the current wallpaper has type DEFAULT, the new customized default
+  // wallpaper should be shown immediately to update the screen. It shouldn't
+  // replace wallpapers of other types.
+  bool show_wallpaper = (GetWallpaperType() == wallpaper::DEFAULT);
+
+  // Customized default wallpapers are subject to the same restrictions as other
+  // default wallpapers, e.g. they should not be set during guest sessions.
+  // TODO(crbug.com/776464): Find a way to directly set wallpaper from here, or
+  // combine this method with |SetDefaultWallpaperImpl|.
+  SetDefaultWallpaperImpl(EmptyAccountId(), user_manager::USER_TYPE_REGULAR,
+                          show_wallpaper);
 }
 
 void WallpaperController::SetPolicyWallpaper(
@@ -1219,7 +1223,7 @@ void WallpaperController::UpdateCustomWallpaperLayout(
   }
   WallpaperInfo info;
   if (!GetUserWallpaperInfo(user_info->account_id, &info,
-                            !user_info->is_ephemeral) ||
+                            user_info->is_ephemeral) ||
       info.type != wallpaper::CUSTOMIZED) {
     return;
   }
@@ -1227,7 +1231,7 @@ void WallpaperController::UpdateCustomWallpaperLayout(
     return;
 
   info.layout = layout;
-  SetUserWallpaperInfo(user_info->account_id, info, !user_info->is_ephemeral);
+  SetUserWallpaperInfo(user_info->account_id, info, user_info->is_ephemeral);
   ShowUserWallpaper(std::move(user_info));
 }
 
@@ -1247,13 +1251,13 @@ void WallpaperController::ShowUserWallpaper(
   }
 
   const AccountId account_id = current_user_->account_id;
-  const bool is_persistent = !current_user_->is_ephemeral;
+  const bool is_ephemeral = current_user_->is_ephemeral;
   // Guest user or regular user in ephemeral mode.
   // TODO(wzang/xdai): Check if the wallpaper info for ephemeral users should
   // be saved to local state.
-  if ((!is_persistent && current_user_->has_gaia_account) ||
+  if ((is_ephemeral && current_user_->has_gaia_account) ||
       current_user_->type == user_manager::USER_TYPE_GUEST) {
-    InitializeUserWallpaperInfo(account_id, is_persistent);
+    InitializeUserWallpaperInfo(account_id, is_ephemeral);
     SetDefaultWallpaperImpl(account_id, current_user_->type,
                             true /*show_wallpaper=*/);
     LOG(ERROR) << "User is ephemeral or guest! Fallback to default wallpaper.";
@@ -1261,9 +1265,9 @@ void WallpaperController::ShowUserWallpaper(
   }
 
   WallpaperInfo info;
-  if (!GetUserWallpaperInfo(account_id, &info, is_persistent)) {
-    InitializeUserWallpaperInfo(account_id, is_persistent);
-    GetUserWallpaperInfo(account_id, &info, is_persistent);
+  if (!GetUserWallpaperInfo(account_id, &info, is_ephemeral)) {
+    InitializeUserWallpaperInfo(account_id, is_ephemeral);
+    GetUserWallpaperInfo(account_id, &info, is_ephemeral);
   }
 
   gfx::ImageSkia user_wallpaper;
@@ -1290,7 +1294,7 @@ void WallpaperController::ShowUserWallpaper(
 
   base::FilePath wallpaper_path;
   if (info.type == wallpaper::DEVICE) {
-    wallpaper_path = GetDeviceWallpaperFilePath();
+    wallpaper_path = GetDevicePolicyWallpaperFilePath();
   } else {
     std::string sub_dir = GetCustomWallpaperSubdirForCurrentResolution();
     // Wallpaper is not resized when layout is
@@ -1335,36 +1339,34 @@ void WallpaperController::ShowSigninWallpaper() {
 void WallpaperController::RemoveUserWallpaper(
     mojom::WallpaperUserInfoPtr user_info,
     const std::string& wallpaper_files_id) {
-  RemoveUserWallpaperInfo(user_info->account_id, !user_info->is_ephemeral);
+  RemoveUserWallpaperInfo(user_info->account_id, user_info->is_ephemeral);
   RemoveUserWallpaperImpl(user_info->account_id, wallpaper_files_id);
 }
 
 void WallpaperController::RemovePolicyWallpaper(
     mojom::WallpaperUserInfoPtr user_info,
     const std::string& wallpaper_files_id) {
-  DCHECK(IsPolicyControlled(user_info->account_id, !user_info->is_ephemeral));
+  DCHECK(IsPolicyControlled(user_info->account_id, user_info->is_ephemeral));
   // Updates the screen only when the user has logged in.
   const bool show_wallpaper =
       Shell::Get()->session_controller()->IsActiveUserSessionStarted();
   // Removes the wallpaper info so that the user is no longer policy controlled,
   // otherwise setting default wallpaper is not allowed.
-  RemoveUserWallpaperInfo(user_info->account_id, !user_info->is_ephemeral);
+  RemoveUserWallpaperInfo(user_info->account_id, user_info->is_ephemeral);
   SetDefaultWallpaper(std::move(user_info), wallpaper_files_id, show_wallpaper);
 }
 
+void WallpaperController::SetAnimationDuration(
+    base::TimeDelta animation_duration) {
+  animation_duration_ = animation_duration;
+}
+
 void WallpaperController::OpenWallpaperPickerIfAllowed() {
   if (wallpaper_controller_client_ && CanOpenWallpaperPicker()) {
     wallpaper_controller_client_->OpenWallpaperPicker();
   }
 }
 
-void WallpaperController::SetWallpaper(const SkBitmap& wallpaper,
-                                       const WallpaperInfo& info) {
-  if (wallpaper.isNull())
-    return;
-  SetWallpaperImage(gfx::ImageSkia::CreateFrom1xBitmap(wallpaper), info);
-}
-
 void WallpaperController::AddObserver(
     mojom::WallpaperObserverAssociatedPtrInfo observer) {
   mojom::WallpaperObserverAssociatedPtr observer_ptr;
@@ -1414,18 +1416,21 @@ void WallpaperController::InitializePathsForTesting() {
 }
 
 void WallpaperController::ShowDefaultWallpaperForTesting() {
-  cached_default_wallpaper_.image = CreateSolidColorWallpaper();
-  cached_default_wallpaper_.file_path.clear();
-  SetWallpaperImage(cached_default_wallpaper_.image,
-                    wallpaper::WallpaperInfo(
-                        "", wallpaper::WALLPAPER_LAYOUT_STRETCH,
-                        wallpaper::DEFAULT, base::Time::Now().LocalMidnight()));
+  SetDefaultWallpaperImpl(EmptyAccountId(), user_manager::USER_TYPE_REGULAR,
+                          true /*show_wallpaper=*/);
+}
+
+void WallpaperController::CreateEmptyWallpaperForTesting() {
+  SetProminentColors(
+      std::vector<SkColor>(color_profiles_.size(), kInvalidColor));
+  current_wallpaper_.reset();
+  wallpaper_mode_ = WALLPAPER_IMAGE;
+  InstallDesktopControllerForAllWindows();
 }
 
 void WallpaperController::SetClientForTesting(
     mojom::WallpaperControllerClientPtr client) {
-  Init(std::move(client), base::FilePath(), base::FilePath(), base::FilePath(),
-       false /*is_device_wallpaper_policy_enforced=*/);
+  wallpaper_controller_client_ = std::move(client);
 }
 
 void WallpaperController::FlushForTesting() {
@@ -1435,26 +1440,12 @@ void WallpaperController::FlushForTesting() {
 }
 
 void WallpaperController::InstallDesktopController(aura::Window* root_window) {
-  WallpaperWidgetController* component = nullptr;
-  int container_id = GetWallpaperContainerId(locked_);
-
-  switch (wallpaper_mode_) {
-    case WALLPAPER_IMAGE: {
-      component = new WallpaperWidgetController(
-          CreateWallpaper(root_window, container_id));
-      break;
-    }
-    case WALLPAPER_NONE:
-      NOTREACHED();
-      return;
-  }
+  DCHECK_EQ(WALLPAPER_IMAGE, wallpaper_mode_);
 
   bool is_wallpaper_blurred = false;
   auto* session_controller = Shell::Get()->session_controller();
-  if (session_controller->IsUserSessionBlocked() && IsBlurEnabled()) {
-    component->SetWallpaperBlur(login_constants::kBlurSigma);
+  if (session_controller->IsUserSessionBlocked() && IsBlurEnabled())
     is_wallpaper_blurred = true;
-  }
 
   if (is_wallpaper_blurred_ != is_wallpaper_blurred) {
     is_wallpaper_blurred_ = is_wallpaper_blurred;
@@ -1464,11 +1455,13 @@ void WallpaperController::InstallDesktopController(aura::Window* root_window) {
       observer.OnWallpaperBlurChanged();
   }
 
-  RootWindowController* controller =
-      RootWindowController::ForWindow(root_window);
-  controller->SetAnimatingWallpaperWidgetController(
-      new AnimatingWallpaperWidgetController(component));
-  component->StartAnimating(controller);
+  const int container_id = GetWallpaperContainerId(locked_);
+  RootWindowController::ForWindow(root_window)
+      ->wallpaper_widget_controller()
+      ->SetWallpaperWidget(CreateWallpaperWidget(root_window, container_id),
+                           is_wallpaper_blurred
+                               ? login_constants::kBlurSigma
+                               : login_constants::kClearBlurSigma);
 }
 
 void WallpaperController::InstallDesktopControllerForAllWindows() {
@@ -1480,27 +1473,9 @@ void WallpaperController::InstallDesktopControllerForAllWindows() {
 bool WallpaperController::ReparentWallpaper(int container) {
   bool moved = false;
   for (auto* root_window_controller : Shell::GetAllRootWindowControllers()) {
-    // In the steady state (no animation playing) the wallpaper widget
-    // controller exists in the RootWindowController.
-    WallpaperWidgetController* wallpaper_widget_controller =
-        root_window_controller->wallpaper_widget_controller();
-    if (wallpaper_widget_controller) {
-      moved |= wallpaper_widget_controller->Reparent(
-          root_window_controller->GetRootWindow(), container);
-    }
-    // During wallpaper show animations the controller lives in
-    // AnimatingWallpaperWidgetController owned by RootWindowController.
-    // NOTE: If an image load happens during a wallpaper show animation there
-    // can temporarily be two wallpaper widgets. We must reparent both of them,
-    // one above and one here.
-    WallpaperWidgetController* animating_controller =
-        root_window_controller->animating_wallpaper_widget_controller()
-            ? root_window_controller->animating_wallpaper_widget_controller()
-                  ->GetController(false)
-            : nullptr;
-    if (animating_controller) {
-      moved |= animating_controller->Reparent(
-          root_window_controller->GetRootWindow(), container);
+    if (root_window_controller->wallpaper_widget_controller()->Reparent(
+            root_window_controller->GetRootWindow(), container)) {
+      moved = true;
     }
   }
   return moved;
@@ -1512,7 +1487,7 @@ int WallpaperController::GetWallpaperContainerId(bool locked) {
 }
 
 void WallpaperController::RemoveUserWallpaperInfo(const AccountId& account_id,
-                                                  bool is_persistent) {
+                                                  bool is_ephemeral) {
   if (wallpaper_cache_map_.find(account_id) != wallpaper_cache_map_.end())
     wallpaper_cache_map_.erase(account_id);
 
@@ -1521,7 +1496,7 @@ void WallpaperController::RemoveUserWallpaperInfo(const AccountId& account_id,
   if (!local_state)
     return;
   WallpaperInfo info;
-  GetUserWallpaperInfo(account_id, &info, is_persistent);
+  GetUserWallpaperInfo(account_id, &info, is_ephemeral);
   DictionaryPrefUpdate prefs_wallpapers_info_update(local_state,
                                                     prefs::kUserWallpaperInfo);
   prefs_wallpapers_info_update->RemoveWithoutPathExpansion(
@@ -1699,7 +1674,7 @@ void WallpaperController::SaveAndSetWallpaper(
   // appropriate wallpaper resolution.
   WallpaperInfo info = {relative_path, layout, type,
                         base::Time::Now().LocalMidnight()};
-  SetUserWallpaperInfo(user_info->account_id, info, !user_info->is_ephemeral);
+  SetUserWallpaperInfo(user_info->account_id, info, user_info->is_ephemeral);
   if (show_wallpaper)
     SetWallpaperImage(image, info);
 
@@ -1871,7 +1846,7 @@ bool WallpaperController::IsActiveUserWallpaperControlledByPolicyImpl() {
   if (!active_user_session)
     return false;
   return IsPolicyControlled(active_user_session->user_info->account_id,
-                            !active_user_session->user_info->is_ephemeral);
+                            active_user_session->user_info->is_ephemeral);
 }
 
 bool WallpaperController::ShouldShowWallpaperSettingImpl() {
