@@ -162,13 +162,8 @@ class ASH_EXPORT WallpaperController
                                      int preferred_height,
                                      gfx::ImageSkia* output_skia);
 
-  // TODO(crbug.com/776464): These utility functions for device policy wallpaper
-  // are temporary during the refactoring.
-  // Returns the file directory where the downloaded device wallpaper is saved.
-  static base::FilePath GetDeviceWallpaperDir();
-
-  // Returns the full path for the downloaded device wallpaper.
-  static base::FilePath GetDeviceWallpaperFilePath();
+  // Returns the file path of the device policy wallpaper.
+  static base::FilePath GetDevicePolicyWallpaperFilePath();
 
   // Gets |account_id|'s custom wallpaper at |wallpaper_path|. Falls back to the
   // original custom wallpaper. When |show_wallpaper| is true, shows the
@@ -202,9 +197,6 @@ class ASH_EXPORT WallpaperController
                                       int height,
                                       SkColor color);
 
-  // Returns the expected file path of the device policy wallpaper.
-  static base::FilePath GetDevicePolicyWallpaperFilePath();
-
   // Binds the mojom::WallpaperController interface request to this object.
   void BindRequest(mojom::WallpaperControllerRequest request);
 
@@ -231,6 +223,16 @@ class ASH_EXPORT WallpaperController
   // no wallpaper.
   wallpaper::WallpaperType GetWallpaperType() const;
 
+  base::TimeDelta animation_duration() const { return animation_duration_; }
+
+  // Returns true if the slower initial animation should be shown (as opposed to
+  // the faster animation that's used e.g. when switching between different
+  // wallpapers at login screen).
+  bool ShouldShowInitialAnimation();
+
+  // Notifies the controller that the wallpaper animation has finished.
+  void OnWallpaperAnimationFinished();
+
   // Returns true if the active user is allowed to open the wallpaper picker.
   bool CanOpenWallpaperPicker();
 
@@ -246,33 +248,14 @@ class ASH_EXPORT WallpaperController
                                const user_manager::UserType& user_type,
                                bool show_wallpaper);
 
-  // TODO(crbug.com/776464): Convert this to a mojo call to replace
-  // |SetCustomizedDefaultWallpaper|. If possible, send the paths together with
-  // |SetClientAndPaths|.
-  // Sets the paths of customized default wallpaper to be used wherever a
-  // default wallpaper is needed. Note: it doesn't change the default wallpaper
-  // for guest and child accounts.
-  void SetCustomizedDefaultWallpaperPaths(
-      const base::FilePath& customized_default_wallpaper_file_small,
-      const base::FilePath& customized_default_wallpaper_file_large);
-
-  // Creates an empty wallpaper. Some tests require a wallpaper widget is ready
-  // when running. However, the wallpaper widgets are now created
-  // asynchronously. If loading a real wallpaper, there are cases that these
-  // tests crash because the required widget is not ready. This function
-  // synchronously creates an empty widget for those tests to prevent
-  // crashes. An example test is SystemGestureEventFilterTest.ThreeFingerSwipe.
-  void CreateEmptyWallpaper();
-
   // Returns whether a wallpaper policy is enforced for |account_id| (not
   // including device policy).
-  bool IsPolicyControlled(const AccountId& account_id,
-                          bool is_persistent) const;
+  bool IsPolicyControlled(const AccountId& account_id, bool is_ephemeral) const;
 
   // When kiosk app is running or policy is enforced, setting a user wallpaper
   // is not allowed.
   bool CanSetUserWallpaper(const AccountId& account_id,
-                           bool is_persistent) const;
+                           bool is_ephemeral) const;
 
   // Prepares wallpaper to lock screen transition. Will apply blur if
   // |locking| is true and remove it otherwise.
@@ -320,24 +303,22 @@ class ASH_EXPORT WallpaperController
   // Returns whether the current wallpaper is blurred.
   bool IsWallpaperBlurred() const { return is_wallpaper_blurred_; }
 
-  // TODO(crbug.com/776464): Change |is_persistent| to |is_ephemeral| to
-  // be consistent with |mojom::WallpaperUserInfo|.
   // Sets wallpaper info for |account_id| and saves it to local state if
-  // |is_persistent| is true.
+  // |is_ephemeral| is false.
   void SetUserWallpaperInfo(const AccountId& account_id,
                             const wallpaper::WallpaperInfo& info,
-                            bool is_persistent);
+                            bool is_ephemeral);
 
   // Gets wallpaper info of |account_id| from local state, or memory if
-  // |is_persistent| is false. Returns false if wallpaper info is not found.
+  // |is_ephemeral| is true. Returns false if wallpaper info is not found.
   bool GetUserWallpaperInfo(const AccountId& account_id,
                             wallpaper::WallpaperInfo* info,
-                            bool is_persistent) const;
+                            bool is_ephemeral) const;
 
   // Initializes wallpaper info for the user to default and saves it to local
-  // state if |is_persistent| is true.
+  // state if |is_ephemeral| is false.
   void InitializeUserWallpaperInfo(const AccountId& account_id,
-                                   bool is_persistent);
+                                   bool is_ephemeral);
 
   // TODO(crbug.com/776464): This method is a temporary workaround during the
   // refactoring. It should be combined with |SetCustomWallpaper|.
@@ -364,7 +345,7 @@ class ASH_EXPORT WallpaperController
   // login screen right now.
   bool ShouldSetDevicePolicyWallpaper() const;
 
-  // mojom::WallpaperController overrides:
+  // mojom::WallpaperController:
   void Init(mojom::WallpaperControllerClientPtr client,
             const base::FilePath& user_data_path,
             const base::FilePath& chromeos_wallpapers_path,
@@ -384,10 +365,9 @@ class ASH_EXPORT WallpaperController
   void SetDefaultWallpaper(mojom::WallpaperUserInfoPtr user_info,
                            const std::string& wallpaper_files_id,
                            bool show_wallpaper) override;
-  void SetCustomizedDefaultWallpaper(
-      const GURL& wallpaper_url,
-      const base::FilePath& file_path,
-      const base::FilePath& resized_directory) override;
+  void SetCustomizedDefaultWallpaperPaths(
+      const base::FilePath& customized_default_small_path,
+      const base::FilePath& customized_default_large_path) override;
   void SetPolicyWallpaper(mojom::WallpaperUserInfoPtr user_info,
                           const std::string& wallpaper_files_id,
                           const std::string& data) override;
@@ -400,9 +380,8 @@ class ASH_EXPORT WallpaperController
                            const std::string& wallpaper_files_id) override;
   void RemovePolicyWallpaper(mojom::WallpaperUserInfoPtr user_info,
                              const std::string& wallpaper_files_id) override;
+  void SetAnimationDuration(base::TimeDelta animation_duration) override;
   void OpenWallpaperPickerIfAllowed() override;
-  void SetWallpaper(const SkBitmap& wallpaper,
-                    const wallpaper::WallpaperInfo& wallpaper_info) override;
   void AddObserver(mojom::WallpaperObserverAssociatedPtrInfo observer) override;
   void GetWallpaperColors(GetWallpaperColorsCallback callback) override;
   void IsActiveUserWallpaperControlledByPolicy(
@@ -419,10 +398,17 @@ class ASH_EXPORT WallpaperController
   // Sets dummy values for wallpaper directories.
   void InitializePathsForTesting();
 
-  // Shows a solid color wallpaper as the substitute for default wallpapers and
-  // updates |default_wallpaper_image_|.
+  // Shows a default wallpaper for testing, without changing users' wallpaper
+  // info.
   void ShowDefaultWallpaperForTesting();
 
+  // Creates an empty wallpaper. Some tests require a wallpaper widget is ready
+  // when running. However, the wallpaper widgets are created asynchronously. If
+  // loading a real wallpaper, there are cases that these tests crash because
+  // the required widget is not ready. This function synchronously creates an
+  // empty widget for those tests to prevent crashes.
+  void CreateEmptyWallpaperForTesting();
+
   // Sets a test client interface with empty file paths.
   void SetClientForTesting(mojom::WallpaperControllerClientPtr client);
 
@@ -456,7 +442,7 @@ class ASH_EXPORT WallpaperController
   int GetWallpaperContainerId(bool locked);
 
   // Removes |account_id|'s wallpaper info and color cache if it exists.
-  void RemoveUserWallpaperInfo(const AccountId& account_id, bool is_persistent);
+  void RemoveUserWallpaperInfo(const AccountId& account_id, bool is_ephemeral);
 
   // Implementation of |RemoveUserWallpaper|, which deletes |account_id|'s
   // custom wallpapers and directories.
@@ -603,8 +589,8 @@ class ASH_EXPORT WallpaperController
   CachedDefaultWallpaper cached_default_wallpaper_;
 
   // The paths of the customized default wallpapers, if they exist.
-  base::FilePath customized_default_wallpaper_small_;
-  base::FilePath customized_default_wallpaper_large_;
+  base::FilePath customized_default_small_path_;
+  base::FilePath customized_default_large_path_;
 
   gfx::Size current_max_display_size_;
 
@@ -614,9 +600,16 @@ class ASH_EXPORT WallpaperController
 
   bool is_wallpaper_blurred_ = false;
 
+  // The wallpaper animation duration. An empty value disables the animation.
+  base::TimeDelta animation_duration_;
+
   // Whether the device wallpaper policy is enforced on this device.
   bool is_device_wallpaper_policy_enforced_ = false;
 
+  // Whether the current wallpaper (if any) is the first wallpaper since the
+  // controller initialization. Empty wallpapers for testing don't count.
+  bool is_first_wallpaper_ = false;
+
   scoped_refptr<base::SequencedTaskRunner> sequenced_task_runner_;
 
   ScopedSessionObserver scoped_session_observer_;
