@@ -252,10 +252,10 @@ class WallpaperControllerTest : public AshTestBase {
     AshTestBase::SetUp();
     // Ash shell initialization creates wallpaper. Reset it so we can manually
     // control wallpaper creation and animation in our tests.
-    RootWindowController* root_window_controller =
-        Shell::Get()->GetPrimaryRootWindowController();
-    root_window_controller->SetWallpaperWidgetController(nullptr);
-    root_window_controller->SetAnimatingWallpaperWidgetController(nullptr);
+    Shell::Get()
+        ->GetPrimaryRootWindowController()
+        ->wallpaper_widget_controller()
+        ->ResetWidgetsForTesting();
     controller_ = Shell::Get()->wallpaper_controller();
     controller_->set_wallpaper_reload_delay_for_test(0);
     controller_->InitializePathsForTesting();
@@ -274,11 +274,11 @@ class WallpaperControllerTest : public AshTestBase {
     WallpaperWidgetController* controller =
         Shell::Get()
             ->GetPrimaryRootWindowController()
-            ->animating_wallpaper_widget_controller()
-            ->GetController(false);
+            ->wallpaper_widget_controller();
     EXPECT_TRUE(controller);
+    EXPECT_TRUE(controller->GetAnimatingWidget());
     return static_cast<WallpaperView*>(
-        controller->widget()->GetContentsView()->child_at(0));
+        controller->GetAnimatingWidget()->GetContentsView()->child_at(0));
   }
 
  protected:
@@ -316,10 +316,11 @@ class WallpaperControllerTest : public AshTestBase {
     WallpaperWidgetController* controller =
         Shell::Get()
             ->GetPrimaryRootWindowController()
-            ->animating_wallpaper_widget_controller()
-            ->GetController(false);
-    EXPECT_TRUE(controller);
-    ASSERT_NO_FATAL_FAILURE(RunAnimationForWidget(controller->widget()));
+            ->wallpaper_widget_controller();
+    ASSERT_TRUE(controller);
+    ASSERT_TRUE(controller->GetAnimatingWidget());
+    ASSERT_NO_FATAL_FAILURE(
+        RunAnimationForWidget(controller->GetAnimatingWidget()));
   }
 
   // Convenience function to ensure ShouldCalculateColors() returns true.
@@ -389,7 +390,7 @@ class WallpaperControllerTest : public AshTestBase {
         relative_path, WALLPAPER_LAYOUT_CENTER_CROPPED, wallpaper::CUSTOMIZED,
         base::Time::Now().LocalMidnight()};
     controller_->SetUserWallpaperInfo(account_id, info,
-                                      true /*is_persistent=*/);
+                                      false /*is_ephemeral=*/);
   }
 
   // Simulates setting a custom wallpaper by directly setting the wallpaper
@@ -400,7 +401,7 @@ class WallpaperControllerTest : public AshTestBase {
         wallpaper::WallpaperInfo("dummy_file_location", WALLPAPER_LAYOUT_CENTER,
                                  wallpaper::CUSTOMIZED,
                                  base::Time::Now().LocalMidnight()),
-        true /*is_persistent=*/);
+        false /*is_ephemeral=*/);
   }
 
   // Initializes default wallpaper paths "*default_*file" and writes JPEG
@@ -502,7 +503,7 @@ class WallpaperControllerTest : public AshTestBase {
 
 TEST_F(WallpaperControllerTest, BasicReparenting) {
   WallpaperController* controller = Shell::Get()->wallpaper_controller();
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
   // Wallpaper view/window exists in the wallpaper container and nothing is in
   // the lock screen wallpaper container.
@@ -527,27 +528,27 @@ TEST_F(WallpaperControllerTest, BasicReparenting) {
   EXPECT_EQ(0, ChildCountForContainer(kLockScreenWallpaperId));
 }
 
-TEST_F(WallpaperControllerTest, ControllerOwnership) {
+TEST_F(WallpaperControllerTest, SwitchWallpapersWhenNewWallpaperAnimationEnds) {
   // We cannot short-circuit animations for this test.
   ui::ScopedAnimationDurationScaleMode test_duration_mode(
       ui::ScopedAnimationDurationScaleMode::NON_ZERO_DURATION);
 
   // Create the wallpaper and its view.
   WallpaperController* controller = Shell::Get()->wallpaper_controller();
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
   // The new wallpaper is ready to animate.
-  RootWindowController* root_window_controller =
-      Shell::Get()->GetPrimaryRootWindowController();
-  EXPECT_TRUE(root_window_controller->animating_wallpaper_widget_controller()
-                  ->GetController(false));
-  EXPECT_FALSE(root_window_controller->wallpaper_widget_controller());
+  WallpaperWidgetController* widget_controller =
+      Shell::Get()
+          ->GetPrimaryRootWindowController()
+          ->wallpaper_widget_controller();
+  EXPECT_TRUE(widget_controller->GetAnimatingWidget());
+  EXPECT_FALSE(widget_controller->GetWidget());
 
   // Force the animation to play to completion.
   RunDesktopControllerAnimation();
-  EXPECT_FALSE(root_window_controller->animating_wallpaper_widget_controller()
-                   ->GetController(false));
-  EXPECT_TRUE(root_window_controller->wallpaper_widget_controller());
+  EXPECT_FALSE(widget_controller->GetAnimatingWidget());
+  EXPECT_TRUE(widget_controller->GetWidget());
 }
 
 // Test for crbug.com/149043 "Unlock screen, no launcher appears". Ensure we
@@ -559,7 +560,7 @@ TEST_F(WallpaperControllerTest, WallpaperMovementDuringUnlock) {
 
   // Reset wallpaper state, see ControllerOwnership above.
   WallpaperController* controller = Shell::Get()->wallpaper_controller();
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
   // Run wallpaper show animation to completion.
   RunDesktopControllerAnimation();
@@ -569,15 +570,16 @@ TEST_F(WallpaperControllerTest, WallpaperMovementDuringUnlock) {
 
   // Suspend/resume cycle causes wallpaper to refresh, loading a new wallpaper
   // that will animate in on top of the old one.
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
   // In this state we have two wallpaper views stored in different properties.
   // Both are in the lock screen wallpaper container.
-  RootWindowController* root_window_controller =
-      Shell::Get()->GetPrimaryRootWindowController();
-  EXPECT_TRUE(root_window_controller->animating_wallpaper_widget_controller()
-                  ->GetController(false));
-  EXPECT_TRUE(root_window_controller->wallpaper_widget_controller());
+  WallpaperWidgetController* widget_controller =
+      Shell::Get()
+          ->GetPrimaryRootWindowController()
+          ->wallpaper_widget_controller();
+  EXPECT_TRUE(widget_controller->GetAnimatingWidget());
+  EXPECT_TRUE(widget_controller->GetWidget());
   EXPECT_EQ(0, ChildCountForContainer(kWallpaperId));
   EXPECT_EQ(2, ChildCountForContainer(kLockScreenWallpaperId));
 
@@ -606,46 +608,38 @@ TEST_F(WallpaperControllerTest, ChangeWallpaperQuick) {
 
   // Reset wallpaper state, see ControllerOwnership above.
   WallpaperController* controller = Shell::Get()->wallpaper_controller();
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
   // Run wallpaper show animation to completion.
   RunDesktopControllerAnimation();
 
   // Change to a new wallpaper.
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
-  RootWindowController* root_window_controller =
-      Shell::Get()->GetPrimaryRootWindowController();
-  WallpaperWidgetController* animating_controller =
-      root_window_controller->animating_wallpaper_widget_controller()
-          ->GetController(false);
-  EXPECT_TRUE(animating_controller);
-  EXPECT_TRUE(root_window_controller->wallpaper_widget_controller());
+  WallpaperWidgetController* widget_controller =
+      Shell::Get()
+          ->GetPrimaryRootWindowController()
+          ->wallpaper_widget_controller();
+  views::Widget* animating_widget = widget_controller->GetAnimatingWidget();
+  EXPECT_TRUE(animating_widget);
+  EXPECT_TRUE(widget_controller->GetWidget());
 
   // Change to another wallpaper before animation finished.
-  controller->CreateEmptyWallpaper();
+  controller->CreateEmptyWallpaperForTesting();
 
-  // The animating controller should immediately move to wallpaper controller.
-  EXPECT_EQ(animating_controller,
-            root_window_controller->wallpaper_widget_controller());
+  // The animating widget should become active immediately.
+  EXPECT_EQ(animating_widget, widget_controller->GetWidget());
 
-  // Cache the new animating controller.
-  animating_controller =
-      root_window_controller->animating_wallpaper_widget_controller()
-          ->GetController(false);
+  // Cache the new animating widget.
+  animating_widget = widget_controller->GetAnimatingWidget();
 
   // Run wallpaper show animation to completion.
-  ASSERT_NO_FATAL_FAILURE(RunAnimationForWidget(
-      root_window_controller->animating_wallpaper_widget_controller()
-          ->GetController(false)
-          ->widget()));
+  ASSERT_NO_FATAL_FAILURE(RunAnimationForWidget(animating_widget));
 
-  EXPECT_TRUE(root_window_controller->wallpaper_widget_controller());
-  EXPECT_FALSE(root_window_controller->animating_wallpaper_widget_controller()
-                   ->GetController(false));
-  // The wallpaper controller should be the last created animating controller.
-  EXPECT_EQ(animating_controller,
-            root_window_controller->wallpaper_widget_controller());
+  EXPECT_TRUE(widget_controller->GetWidget());
+  EXPECT_FALSE(widget_controller->GetAnimatingWidget());
+  // The last animating widget should be active at this point.
+  EXPECT_EQ(animating_widget, widget_controller->GetWidget());
 }
 
 TEST_F(WallpaperControllerTest, ResizeCustomWallpaper) {
@@ -780,7 +774,7 @@ TEST_F(WallpaperControllerTest, ShouldCalculateColorsBasedOnImage) {
   EnableShelfColoring();
   EXPECT_TRUE(ShouldCalculateColors());
 
-  controller_->CreateEmptyWallpaper();
+  controller_->CreateEmptyWallpaperForTesting();
   EXPECT_FALSE(ShouldCalculateColors());
 }
 
@@ -847,7 +841,7 @@ TEST_F(WallpaperControllerTest, SetCustomWallpaper) {
   EXPECT_EQ(controller_->GetWallpaperType(), wallpaper::CUSTOMIZED);
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo expected_wallpaper_info(
       base::FilePath(wallpaper_files_id_1).Append(file_name_1).value(), layout,
       wallpaper::CUSTOMIZED, base::Time::Now().LocalMidnight());
@@ -861,7 +855,7 @@ TEST_F(WallpaperControllerTest, SetCustomWallpaper) {
   RunAllTasksUntilIdle();
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, expected_wallpaper_info);
 }
 
@@ -880,7 +874,7 @@ TEST_F(WallpaperControllerTest, SetOnlineWallpaper) {
   EXPECT_EQ(controller_->GetWallpaperType(), wallpaper::ONLINE);
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo expected_wallpaper_info(
       url, layout, wallpaper::ONLINE, base::Time::Now().LocalMidnight());
   EXPECT_EQ(wallpaper_info, expected_wallpaper_info);
@@ -892,7 +886,7 @@ TEST_F(WallpaperControllerTest, SetOnlineWallpaper) {
   RunAllTasksUntilIdle();
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, expected_wallpaper_info);
 }
 
@@ -904,9 +898,9 @@ TEST_F(WallpaperControllerTest, SetAndRemovePolicyWallpaper) {
   // The user starts with no wallpaper info and is not controlled by policy.
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_FALSE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                 true /*is_persistent=*/));
+                                                 false /*is_ephemeral=*/));
   EXPECT_FALSE(
-      controller_->IsPolicyControlled(account_id_1, true /*is_persistent=*/));
+      controller_->IsPolicyControlled(account_id_1, false /*is_ephemeral=*/));
   // A default wallpaper is shown for the user.
   controller_->ShowUserWallpaper(InitializeUser(account_id_1));
   EXPECT_EQ(1, GetWallpaperCount());
@@ -919,7 +913,7 @@ TEST_F(WallpaperControllerTest, SetAndRemovePolicyWallpaper) {
                                   std::string() /*data=*/);
   RunAllTasksUntilIdle();
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo policy_wallpaper_info(
       base::FilePath(wallpaper_files_id_1)
           .Append("policy-controlled.jpeg")
@@ -928,7 +922,7 @@ TEST_F(WallpaperControllerTest, SetAndRemovePolicyWallpaper) {
       base::Time::Now().LocalMidnight());
   EXPECT_EQ(wallpaper_info, policy_wallpaper_info);
   EXPECT_TRUE(
-      controller_->IsPolicyControlled(account_id_1, true /*is_persistent=*/));
+      controller_->IsPolicyControlled(account_id_1, false /*is_ephemeral=*/));
   // Verify the wallpaper is not updated since the user hasn't logged in.
   EXPECT_EQ(0, GetWallpaperCount());
 
@@ -945,13 +939,13 @@ TEST_F(WallpaperControllerTest, SetAndRemovePolicyWallpaper) {
                                      wallpaper_files_id_1);
   WaitUntilCustomWallpapersDeleted(account_id_1);
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo default_wallpaper_info(
       std::string(), wallpaper::WALLPAPER_LAYOUT_CENTER_CROPPED,
       wallpaper::DEFAULT, base::Time::Now().LocalMidnight());
   EXPECT_EQ(wallpaper_info, default_wallpaper_info);
   EXPECT_FALSE(
-      controller_->IsPolicyControlled(account_id_1, true /*is_persistent=*/));
+      controller_->IsPolicyControlled(account_id_1, false /*is_ephemeral=*/));
   // Verify the wallpaper is not updated since the user hasn't logged in.
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_EQ(controller_->GetWallpaperType(), wallpaper::POLICY);
@@ -971,7 +965,7 @@ TEST_F(WallpaperControllerTest, SetDefaultWallpaperForRegularAccount) {
   SimulateSettingCustomWallpaper(account_id_1);
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo default_wallpaper_info(
       std::string(), wallpaper::WALLPAPER_LAYOUT_CENTER_CROPPED,
       wallpaper::DEFAULT, base::Time::Now().LocalMidnight());
@@ -992,7 +986,7 @@ TEST_F(WallpaperControllerTest, SetDefaultWallpaperForRegularAccount) {
       {wallpaper_dir_->GetPath().Append(default_large_wallpaper_name)}));
 
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   // The user wallpaper info has been reset to the default value.
   EXPECT_EQ(wallpaper_info, default_wallpaper_info);
 
@@ -1012,7 +1006,7 @@ TEST_F(WallpaperControllerTest, SetDefaultWallpaperForRegularAccount) {
       {wallpaper_dir_->GetPath().Append(default_small_wallpaper_name)}));
 
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   // The user wallpaper info has been reset to the default value.
   EXPECT_EQ(wallpaper_info, default_wallpaper_info);
 
@@ -1032,7 +1026,7 @@ TEST_F(WallpaperControllerTest, SetDefaultWallpaperForRegularAccount) {
       {wallpaper_dir_->GetPath().Append(default_small_wallpaper_name)}));
 
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   // The user wallpaper info has been reset to the default value.
   EXPECT_EQ(wallpaper_info, default_wallpaper_info);
 }
@@ -1085,7 +1079,7 @@ TEST_F(WallpaperControllerTest, SetDefaultWallpaperForGuestSession) {
   SimulateSettingCustomWallpaper(account_id_1);
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo default_wallpaper_info(
       std::string(), wallpaper::WALLPAPER_LAYOUT_CENTER_CROPPED,
       wallpaper::DEFAULT, base::Time::Now().LocalMidnight());
@@ -1105,7 +1099,7 @@ TEST_F(WallpaperControllerTest, SetDefaultWallpaperForGuestSession) {
   EXPECT_EQ(1, GetWallpaperCount());
   EXPECT_EQ(controller_->GetWallpaperType(), wallpaper::DEFAULT);
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, default_wallpaper_info);
   EXPECT_TRUE(CompareDecodeFilePaths(
       {wallpaper_dir_->GetPath().Append(guest_large_wallpaper_name)}));
@@ -1141,7 +1135,7 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestInKioskMode) {
   EXPECT_EQ(0, GetWallpaperCount());
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_FALSE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                 true /* is_persistent */));
+                                                 false /*is_ephemeral=*/));
 
   // Verify that |SetOnlineWallpaper| doesn't set wallpaper in kiosk mode, and
   // |account_id|'s wallpaper info is not updated.
@@ -1151,7 +1145,7 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestInKioskMode) {
   RunAllTasksUntilIdle();
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_FALSE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                 true /*is_persistent=*/));
+                                                 false /*is_ephemeral=*/));
 
   // Verify that |SetDefaultWallpaper| doesn't set wallpaper in kiosk mode, and
   // |account_id|'s wallpaper info is not updated.
@@ -1161,7 +1155,7 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestInKioskMode) {
   RunAllTasksUntilIdle();
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_FALSE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                 true /*is_persistent=*/));
+                                                 false /*is_ephemeral=*/));
 }
 
 TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestWhenPolicyIsEnforced) {
@@ -1174,9 +1168,9 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestWhenPolicyIsEnforced) {
       "dummy_file_location", WALLPAPER_LAYOUT_CENTER, wallpaper::POLICY,
       base::Time::Now().LocalMidnight());
   controller_->SetUserWallpaperInfo(account_id_1, policy_wallpaper_info,
-                                    true /*is_persistent=*/);
+                                    false /*is_ephemeral=*/);
   EXPECT_TRUE(
-      controller_->IsPolicyControlled(account_id_1, true /*is_persistent=*/));
+      controller_->IsPolicyControlled(account_id_1, false /*is_ephemeral=*/));
 
   // Verify that |SetCustomWallpaper| doesn't set wallpaper when policy is
   // enforced, and |account_id|'s wallpaper info is not updated.
@@ -1187,7 +1181,7 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestWhenPolicyIsEnforced) {
   EXPECT_EQ(0, GetWallpaperCount());
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, policy_wallpaper_info);
 
   // Verify that |SetOnlineWallpaper| doesn't set wallpaper when policy is
@@ -1198,7 +1192,7 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestWhenPolicyIsEnforced) {
   RunAllTasksUntilIdle();
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, policy_wallpaper_info);
 
   // Verify that |SetDefaultWallpaper| doesn't set wallpaper when policy is
@@ -1209,7 +1203,7 @@ TEST_F(WallpaperControllerTest, IgnoreWallpaperRequestWhenPolicyIsEnforced) {
   RunAllTasksUntilIdle();
   EXPECT_EQ(0, GetWallpaperCount());
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, policy_wallpaper_info);
 }
 
@@ -1383,7 +1377,7 @@ TEST_F(WallpaperControllerTest, UpdateCustomWallpaperLayout) {
   EXPECT_EQ(controller_->GetWallpaperLayout(), layout);
   wallpaper::WallpaperInfo wallpaper_info;
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   wallpaper::WallpaperInfo expected_wallpaper_info(
       base::FilePath(wallpaper_files_id_1).Append(file_name_1).value(), layout,
       wallpaper::CUSTOMIZED, base::Time::Now().LocalMidnight());
@@ -1398,7 +1392,7 @@ TEST_F(WallpaperControllerTest, UpdateCustomWallpaperLayout) {
   EXPECT_EQ(1, GetWallpaperCount());
   EXPECT_EQ(controller_->GetWallpaperLayout(), layout);
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   expected_wallpaper_info.layout = layout;
   EXPECT_EQ(wallpaper_info, expected_wallpaper_info);
 
@@ -1412,7 +1406,7 @@ TEST_F(WallpaperControllerTest, UpdateCustomWallpaperLayout) {
   EXPECT_EQ(1, GetWallpaperCount());
   EXPECT_EQ(controller_->GetWallpaperType(), wallpaper::ONLINE);
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /*is_persistent=*/));
+                                                false /*is_ephemeral=*/));
   expected_wallpaper_info.type = wallpaper::ONLINE;
   expected_wallpaper_info.location = url;
   EXPECT_EQ(wallpaper_info, expected_wallpaper_info);
@@ -1426,7 +1420,7 @@ TEST_F(WallpaperControllerTest, UpdateCustomWallpaperLayout) {
   EXPECT_EQ(controller_->GetWallpaperLayout(), layout);
   // The saved wallpaper info is not updated.
   EXPECT_TRUE(controller_->GetUserWallpaperInfo(account_id_1, &wallpaper_info,
-                                                true /* is_persistent */));
+                                                false /*is_ephemeral=*/));
   EXPECT_EQ(wallpaper_info, expected_wallpaper_info);
 }
 
@@ -1655,4 +1649,69 @@ TEST_F(WallpaperControllerTest, OnlyShowDevicePolicyWallpaperOnLoginScreen) {
   EXPECT_FALSE(IsDevicePolicyWallpaper());
 }
 
+TEST_F(WallpaperControllerTest, ShouldShowInitialAnimationAfterBoot) {
+  CreateDefaultWallpapers();
+
+  // Simulate the login screen after system boot.
+  base::CommandLine::ForCurrentProcess()->AppendSwitch(
+      chromeos::switches::kFirstExecAfterBoot);
+  base::CommandLine::ForCurrentProcess()->AppendSwitch(
+      chromeos::switches::kLoginManager);
+  ClearLogin();
+
+  // Show the first wallpaper. Verify that the slower animation should be used.
+  controller_->ShowUserWallpaper(InitializeUser(account_id_1));
+  RunAllTasksUntilIdle();
+  EXPECT_TRUE(controller_->ShouldShowInitialAnimation());
+  EXPECT_EQ(1, GetWallpaperCount());
+
+  // Show the second wallpaper. Verify that the slower animation should not be
+  // used. (Use a different user type to ensure a different wallpaper is shown,
+  // otherwise requests of loading the same wallpaper are ignored.)
+  controller_->ShowUserWallpaper(
+      InitializeUser(AccountId::FromUserEmail("child@test.com")));
+  RunAllTasksUntilIdle();
+  EXPECT_FALSE(controller_->ShouldShowInitialAnimation());
+  EXPECT_EQ(1, GetWallpaperCount());
+
+  // Log in the user and show the wallpaper. Verify that the slower animation
+  // should not be used.
+  SimulateUserLogin(user_1);
+  controller_->ShowUserWallpaper(InitializeUser(account_id_1));
+  RunAllTasksUntilIdle();
+  EXPECT_FALSE(controller_->ShouldShowInitialAnimation());
+  EXPECT_EQ(1, GetWallpaperCount());
+}
+
+TEST_F(WallpaperControllerTest, ShouldNotShowInitialAnimationAfterSignOut) {
+  CreateDefaultWallpapers();
+
+  // Simulate the login screen after user sign-out. Verify that the slower
+  // animation should never be used.
+  base::CommandLine::ForCurrentProcess()->AppendSwitch(
+      chromeos::switches::kLoginManager);
+  CreateAndSaveWallpapers(account_id_1);
+  ClearLogin();
+
+  // Show the first wallpaper.
+  controller_->ShowUserWallpaper(InitializeUser(account_id_1));
+  RunAllTasksUntilIdle();
+  EXPECT_FALSE(controller_->ShouldShowInitialAnimation());
+  EXPECT_EQ(1, GetWallpaperCount());
+
+  // Show the second wallpaper.
+  controller_->ShowUserWallpaper(
+      InitializeUser(AccountId::FromUserEmail("child@test.com")));
+  RunAllTasksUntilIdle();
+  EXPECT_FALSE(controller_->ShouldShowInitialAnimation());
+  EXPECT_EQ(1, GetWallpaperCount());
+
+  // Log in the user and show the wallpaper.
+  SimulateUserLogin(user_1);
+  controller_->ShowUserWallpaper(InitializeUser(account_id_1));
+  RunAllTasksUntilIdle();
+  EXPECT_FALSE(controller_->ShouldShowInitialAnimation());
+  EXPECT_EQ(1, GetWallpaperCount());
+}
+
 }  // namespace ash
