@@ -8,12 +8,16 @@
 #include <memory>
 #include <vector>
 
+#include "ash/public/cpp/ash_switches.h"
 #include "ash/wm/overview/overview_utils.h"
+#include "ash/wm/overview/overview_window_animation_observer.h"
 #include "ash/wm/overview/scoped_overview_animation_settings.h"
+#include "ash/wm/overview/window_grid.h"
 #include "ash/wm/overview/window_selector_item.h"
 #include "ash/wm/splitview/split_view_controller.h"
 #include "ash/wm/window_mirror_view.h"
 #include "ash/wm/window_state.h"
+#include "ash/wm/window_transient_descendant_iterator.h"
 #include "ash/wm/window_util.h"
 #include "base/macros.h"
 #include "base/single_thread_task_runner.h"
@@ -67,125 +71,6 @@ ScopedTransformOverviewWindow::GridWindowFillMode GetWindowDimensionsType(
   return ScopedTransformOverviewWindow::GridWindowFillMode::kNormal;
 }
 
-// An iterator class that traverses an aura::Window and all of its transient
-// descendants.
-class TransientDescendantIterator {
- public:
-  // Creates an empty iterator.
-  TransientDescendantIterator();
-
-  // Copy constructor required for iterator purposes.
-  TransientDescendantIterator(const TransientDescendantIterator& other) =
-      default;
-
-  // Iterates over |root_window| and all of its transient descendants.
-  // Note |root_window| must not have a transient parent.
-  explicit TransientDescendantIterator(aura::Window* root_window);
-
-  // Prefix increment operator.  This assumes there are more items (i.e.
-  // *this != TransientDescendantIterator()).
-  const TransientDescendantIterator& operator++();
-
-  // Comparison for STL-based loops.
-  bool operator!=(const TransientDescendantIterator& other) const;
-
-  // Dereference operator for STL-compatible iterators.
-  aura::Window* operator*() const;
-
- private:
-  // Explicit assignment operator defined because an explicit copy constructor
-  // is needed and therefore the DISALLOW_COPY_AND_ASSIGN macro cannot be used.
-  TransientDescendantIterator& operator=(
-      const TransientDescendantIterator& other) = default;
-
-  // The current window that |this| refers to. A null |current_window_| denotes
-  // an empty iterator and is used as the last possible value in the traversal.
-  aura::Window* current_window_;
-};
-
-// Provides a virtual container implementing begin() and end() for a sequence of
-// TransientDescendantIterators. This can be used in range-based for loops.
-class TransientDescendantIteratorRange {
- public:
-  explicit TransientDescendantIteratorRange(
-      const TransientDescendantIterator& begin);
-
-  // Copy constructor required for iterator purposes.
-  TransientDescendantIteratorRange(
-      const TransientDescendantIteratorRange& other) = default;
-
-  const TransientDescendantIterator& begin() const { return begin_; }
-  const TransientDescendantIterator& end() const { return end_; }
-
- private:
-  // Explicit assignment operator defined because an explicit copy constructor
-  // is needed and therefore the DISALLOW_COPY_AND_ASSIGN macro cannot be used.
-  TransientDescendantIteratorRange& operator=(
-      const TransientDescendantIteratorRange& other) = default;
-
-  TransientDescendantIterator begin_;
-  TransientDescendantIterator end_;
-};
-
-TransientDescendantIterator::TransientDescendantIterator()
-    : current_window_(nullptr) {}
-
-TransientDescendantIterator::TransientDescendantIterator(
-    aura::Window* root_window)
-    : current_window_(root_window) {
-  DCHECK(!::wm::GetTransientParent(root_window));
-}
-
-// Performs a pre-order traversal of the transient descendants.
-const TransientDescendantIterator& TransientDescendantIterator::operator++() {
-  DCHECK(current_window_);
-
-  const aura::Window::Windows transient_children =
-      ::wm::GetTransientChildren(current_window_);
-
-  if (!transient_children.empty()) {
-    current_window_ = transient_children.front();
-  } else {
-    while (current_window_) {
-      aura::Window* parent = ::wm::GetTransientParent(current_window_);
-      if (!parent) {
-        current_window_ = nullptr;
-        break;
-      }
-      const aura::Window::Windows transient_siblings =
-          ::wm::GetTransientChildren(parent);
-      auto iter = std::find(transient_siblings.begin(),
-                            transient_siblings.end(), current_window_);
-      ++iter;
-      if (iter != transient_siblings.end()) {
-        current_window_ = *iter;
-        break;
-      }
-      current_window_ = ::wm::GetTransientParent(current_window_);
-    }
-  }
-  return *this;
-}
-
-bool TransientDescendantIterator::operator!=(
-    const TransientDescendantIterator& other) const {
-  return current_window_ != other.current_window_;
-}
-
-aura::Window* TransientDescendantIterator::operator*() const {
-  return current_window_;
-}
-
-TransientDescendantIteratorRange::TransientDescendantIteratorRange(
-    const TransientDescendantIterator& begin)
-    : begin_(begin) {}
-
-TransientDescendantIteratorRange GetTransientTreeIterator(
-    aura::Window* window) {
-  return TransientDescendantIteratorRange(
-      TransientDescendantIterator(GetTransientRoot(window)));
-}
-
 }  // namespace
 
 class ScopedTransformOverviewWindow::LayerCachingAndFilteringObserver
@@ -276,7 +161,6 @@ ScopedTransformOverviewWindow::ScopedTransformOverviewWindow(
       window_(window),
       ignored_by_shelf_(wm::GetWindowState(window)->ignored_by_shelf()),
       overview_started_(false),
-      original_transform_(window->layer()->GetTargetTransform()),
       original_opacity_(window->layer()->GetTargetOpacity()),
       weak_ptr_factory_(this) {
   if (IsNewOverviewUi())
@@ -285,7 +169,7 @@ ScopedTransformOverviewWindow::ScopedTransformOverviewWindow(
 
 ScopedTransformOverviewWindow::~ScopedTransformOverviewWindow() = default;
 
-void ScopedTransformOverviewWindow::RestoreWindow() {
+void ScopedTransformOverviewWindow::RestoreWindow(bool reset_transform) {
   ::wm::SetShadowElevation(window_, original_shadow_elevation_);
 
   wm::GetWindowState(window_)->set_ignored_by_shelf(ignored_by_shelf_);
@@ -296,41 +180,66 @@ void ScopedTransformOverviewWindow::RestoreWindow() {
     minimized_widget_.reset();
     return;
   }
-  ScopedAnimationSettings animation_settings_list;
-  BeginScopedAnimation(OverviewAnimationType::OVERVIEW_ANIMATION_RESTORE_WINDOW,
-                       &animation_settings_list);
-  SetTransform(window()->GetRootWindow(), original_transform_);
-  // Add requests to cache render surface and perform trilinear filtering for
-  // the exit animation of overview mode. The requests will be removed when the
-  // exit animation finishes.
-  for (auto& settings : animation_settings_list) {
-    settings->CacheRenderSurface();
-    settings->TrilinearFiltering();
+
+  if (reset_transform) {
+    ScopedAnimationSettings animation_settings_list;
+    BeginScopedAnimation(selector_item_->GetExitTransformAnimationType(),
+                         &animation_settings_list);
+    // Use identity transform directly to reset window's transform when exiting
+    // overview.
+    SetTransform(window()->GetRootWindow(), gfx::Transform());
+    // Add requests to cache render surface and perform trilinear filtering for
+    // the exit animation of overview mode. The requests will be removed when
+    // the exit animation finishes.
+    if (switches::IsTrilinearFilteringEnabled()) {
+      for (auto& settings : animation_settings_list) {
+        settings->CacheRenderSurface();
+        settings->TrilinearFiltering();
+      }
+    }
   }
 
   ScopedOverviewAnimationSettings animation_settings(
-      OverviewAnimationType::OVERVIEW_ANIMATION_LAY_OUT_SELECTOR_ITEMS,
-      window_);
+      selector_item_->GetExitOverviewAnimationType(), window_);
   SetOpacity(original_opacity_);
 }
 
 void ScopedTransformOverviewWindow::BeginScopedAnimation(
     OverviewAnimationType animation_type,
     ScopedAnimationSettings* animation_settings) {
+  if (animation_type == OverviewAnimationType::OVERVIEW_ANIMATION_NONE)
+    return;
+
   // Remove the mask before animating because masks affect animation
   // performance. Observe the animation and add the mask after animating if the
   // animation type is layouting selector items.
   if (IsNewOverviewUi()) {
     mask_.reset();
+    selector_item_->SetShadowBounds(base::nullopt);
+    selector_item_->DisableBackdrop();
+
     if (window_->GetProperty(aura::client::kShowStateKey) !=
         ui::SHOW_STATE_MINIMIZED) {
       window_->layer()->SetMaskLayer(original_mask_layer_);
     }
   }
-  for (auto* window : GetTransientTreeIterator(GetOverviewWindow())) {
+  for (auto* window : wm::GetTransientTreeIterator(GetOverviewWindow())) {
     auto settings = std::make_unique<ScopedOverviewAnimationSettings>(
         animation_type, window);
     settings->DeferPaint();
+
+    // If current |window_| is the first MRU window covering the available
+    // workspace, add the |window_animation_observer| to its
+    // ScopedOverviewAnimationSettings in order to monitor the complete of its
+    // exiting animation.
+    if (window == GetOverviewWindow() &&
+        selector_item_->ShouldBeObservedWhenExiting()) {
+      auto window_animation_observer_weak_ptr =
+          selector_item_->window_grid()->window_animation_observer();
+      if (window_animation_observer_weak_ptr)
+        settings->AddObserver(window_animation_observer_weak_ptr.get());
+    }
+
     animation_settings->push_back(std::move(settings));
   }
 
@@ -342,7 +251,7 @@ void ScopedTransformOverviewWindow::BeginScopedAnimation(
 }
 
 bool ScopedTransformOverviewWindow::Contains(const aura::Window* target) const {
-  for (auto* window : GetTransientTreeIterator(window_)) {
+  for (auto* window : wm::GetTransientTreeIterator(window_)) {
     if (window->Contains(target))
       return true;
   }
@@ -353,7 +262,7 @@ bool ScopedTransformOverviewWindow::Contains(const aura::Window* target) const {
 gfx::Rect ScopedTransformOverviewWindow::GetTargetBoundsInScreen() const {
   gfx::Rect bounds;
   aura::Window* overview_window = GetOverviewWindow();
-  for (auto* window : GetTransientTreeIterator(overview_window)) {
+  for (auto* window : wm::GetTransientTreeIterator(overview_window)) {
     // Ignore other window types when computing bounding box of window
     // selector target item.
     if (window != overview_window &&
@@ -372,7 +281,7 @@ gfx::Rect ScopedTransformOverviewWindow::GetTransformedBounds() const {
   const int top_inset = GetTopInset();
   gfx::Rect bounds;
   aura::Window* overview_window = GetOverviewWindow();
-  for (auto* window : GetTransientTreeIterator(overview_window)) {
+  for (auto* window : wm::GetTransientTreeIterator(overview_window)) {
     // Ignore other window types when computing bounding box of window
     // selector target item.
     if (window != overview_window &&
@@ -403,7 +312,7 @@ gfx::Rect ScopedTransformOverviewWindow::GetTransformedBounds() const {
 }
 
 SkColor ScopedTransformOverviewWindow::GetTopColor() const {
-  for (auto* window : GetTransientTreeIterator(window_)) {
+  for (auto* window : wm::GetTransientTreeIterator(window_)) {
     // If there are regular windows in the transient ancestor tree, all those
     // windows are shown in the same overview item and the header is not masked.
     if (window != window_ &&
@@ -419,7 +328,7 @@ int ScopedTransformOverviewWindow::GetTopInset() const {
   // Mirror window doesn't have insets.
   if (minimized_widget_)
     return 0;
-  for (auto* window : GetTransientTreeIterator(window_)) {
+  for (auto* window : wm::GetTransientTreeIterator(window_)) {
     // If there are regular windows in the transient ancestor tree, all those
     // windows are shown in the same overview item and the header is not masked.
     if (window != window_ &&
@@ -458,9 +367,11 @@ void ScopedTransformOverviewWindow::SetTransform(
     aura::Window* root_window,
     const gfx::Transform& transform) {
   DCHECK(overview_started_);
+  auto window_animation_observer_weak_ptr =
+      selector_item_->window_grid()->window_animation_observer();
 
   gfx::Point target_origin(GetTargetBoundsInScreen().origin());
-  for (auto* window : GetTransientTreeIterator(GetOverviewWindow())) {
+  for (auto* window : wm::GetTransientTreeIterator(GetOverviewWindow())) {
     aura::Window* parent_window = window->parent();
     gfx::Rect original_bounds(window->GetTargetBounds());
     ::wm::ConvertRectToScreen(parent_window, &original_bounds);
@@ -468,12 +379,21 @@ void ScopedTransformOverviewWindow::SetTransform(
         TransformAboutPivot(gfx::Point(target_origin.x() - original_bounds.x(),
                                        target_origin.y() - original_bounds.y()),
                             transform);
-    window->SetTransform(new_transform);
+    // If current |window_| should not animate during exiting process, we defer
+    // set transfrom on the window by adding the layer and transform information
+    // to the |window_animation_observer|.
+    if (!selector_item_->ShouldAnimateWhenExiting() &&
+        window_animation_observer_weak_ptr) {
+      window_animation_observer_weak_ptr->AddLayerTransformPair(window->layer(),
+                                                                new_transform);
+    } else {
+      window->SetTransform(new_transform);
+    }
   }
 }
 
 void ScopedTransformOverviewWindow::SetOpacity(float opacity) {
-  for (auto* window : GetTransientTreeIterator(GetOverviewWindow()))
+  for (auto* window : wm::GetTransientTreeIterator(GetOverviewWindow()))
     window->layer()->SetOpacity(opacity);
 }
 
@@ -567,7 +487,7 @@ void ScopedTransformOverviewWindow::Close() {
 
 void ScopedTransformOverviewWindow::PrepareForOverview() {
   original_shadow_elevation_ = window_->GetProperty(::wm::kShadowElevationKey);
-  ::wm::SetShadowElevation(window_, ::wm::ShadowElevation::NONE);
+  ::wm::SetShadowElevation(window_, ::wm::kShadowElevationNone);
 
   DCHECK(!overview_started_);
   overview_started_ = true;
@@ -578,12 +498,14 @@ void ScopedTransformOverviewWindow::PrepareForOverview() {
   }
 
   // Add requests to cache render surface and perform trilinear filtering. The
-  // requests will be removed in dctor. So the requests will be valid during the
+  // requests will be removed in dtor. So the requests will be valid during the
   // enter animation and the whole time during overview mode. For the exit
   // animation of overview mode, we need to add those requests again.
-  for (auto* window : GetTransientTreeIterator(GetOverviewWindow())) {
-    cached_and_filtered_layer_observers_.push_back(
-        std::make_unique<LayerCachingAndFilteringObserver>(window->layer()));
+  if (switches::IsTrilinearFilteringEnabled()) {
+    for (auto* window : wm::GetTransientTreeIterator(GetOverviewWindow())) {
+      cached_and_filtered_layer_observers_.push_back(
+          std::make_unique<LayerCachingAndFilteringObserver>(window->layer()));
+    }
   }
 }
 
@@ -608,77 +530,6 @@ void ScopedTransformOverviewWindow::EnsureVisible() {
   original_opacity_ = 1.f;
 }
 
-void ScopedTransformOverviewWindow::OnGestureEvent(ui::GestureEvent* event) {
-  if (minimized_widget_ && SplitViewController::ShouldAllowSplitView()) {
-    gfx::Point location(event->location());
-    ::wm::ConvertPointToScreen(minimized_widget_->GetNativeWindow(), &location);
-    switch (event->type()) {
-      case ui::ET_GESTURE_TAP_DOWN:
-        selector_item_->HandlePressEvent(location);
-        break;
-      case ui::ET_GESTURE_SCROLL_UPDATE:
-        selector_item_->HandleDragEvent(location);
-        break;
-      case ui::ET_SCROLL_FLING_START:
-      case ui::ET_GESTURE_SCROLL_END:
-        selector_item_->HandleReleaseEvent(location);
-        break;
-      case ui::ET_GESTURE_TAP:
-        selector_item_->ActivateDraggedWindow();
-        break;
-      case ui::ET_GESTURE_END:
-        selector_item_->ResetDraggedWindowGesture();
-        break;
-      default:
-        break;
-    }
-    event->SetHandled();
-  } else if (event->type() == ui::ET_GESTURE_TAP) {
-    EnsureVisible();
-    window_->Show();
-    wm::ActivateWindow(window_);
-  }
-}
-
-void ScopedTransformOverviewWindow::OnMouseEvent(ui::MouseEvent* event) {
-  if (minimized_widget_ && SplitViewController::ShouldAllowSplitView()) {
-    gfx::Point location(event->location());
-    ::wm::ConvertPointToScreen(minimized_widget_->GetNativeWindow(), &location);
-    switch (event->type()) {
-      case ui::ET_MOUSE_PRESSED:
-        selector_item_->HandlePressEvent(location);
-        break;
-      case ui::ET_MOUSE_DRAGGED:
-        selector_item_->HandleDragEvent(location);
-        break;
-      case ui::ET_MOUSE_RELEASED:
-        selector_item_->HandleReleaseEvent(location);
-        break;
-      default:
-        break;
-    }
-    event->SetHandled();
-  } else if (event->type() == ui::ET_MOUSE_PRESSED &&
-             event->IsOnlyLeftMouseButton()) {
-    EnsureVisible();
-    window_->Show();
-    wm::ActivateWindow(window_);
-  }
-}
-
-void ScopedTransformOverviewWindow::OnImplicitAnimationsCompleted() {
-  // Add the mask which gives the window selector items rounded corners.
-  ui::Layer* layer = minimized_widget_
-                         ? minimized_widget_->GetContentsView()->layer()
-                         : window_->layer();
-  if (!minimized_widget_)
-    original_mask_layer_ = window_->layer()->layer_mask_layer();
-  mask_ = std::make_unique<WindowMask>(GetOverviewWindow());
-  mask_->layer()->SetBounds(layer->bounds());
-  mask_->set_top_inset(GetTopInset());
-  layer->SetMaskLayer(mask_->layer());
-}
-
 aura::Window*
 ScopedTransformOverviewWindow::GetOverviewWindowForMinimizedState() const {
   return minimized_widget_ ? minimized_widget_->GetNativeWindow() : nullptr;
@@ -692,6 +543,29 @@ void ScopedTransformOverviewWindow::UpdateWindowDimensionsType() {
   window_selector_bounds_.reset();
 }
 
+void ScopedTransformOverviewWindow::CancelAnimationsListener() {
+  StopObservingImplicitAnimations();
+}
+
+void ScopedTransformOverviewWindow::OnImplicitAnimationsCompleted() {
+  // Add the mask which gives the window selector items rounded corners, and add
+  // the shadow around the window.
+  DCHECK(IsNewOverviewUi());
+
+  ui::Layer* layer = minimized_widget_
+                         ? minimized_widget_->GetContentsView()->layer()
+                         : window_->layer();
+  if (!minimized_widget_)
+    original_mask_layer_ = window_->layer()->layer_mask_layer();
+
+  mask_ = std::make_unique<WindowMask>(GetOverviewWindow());
+  mask_->layer()->SetBounds(layer->bounds());
+  mask_->set_top_inset(GetTopInset());
+  layer->SetMaskLayer(mask_->layer());
+  selector_item_->SetShadowBounds(base::make_optional(GetTransformedBounds()));
+  selector_item_->EnableBackdropIfNeeded();
+}
+
 void ScopedTransformOverviewWindow::CreateMirrorWindowForMinimizedState() {
   DCHECK(!minimized_widget_.get());
   views::Widget::InitParams params;
@@ -700,7 +574,7 @@ void ScopedTransformOverviewWindow::CreateMirrorWindowForMinimizedState() {
   params.visible_on_all_workspaces = true;
   params.name = "OverviewModeMinimized";
   params.activatable = views::Widget::InitParams::Activatable::ACTIVATABLE_NO;
-  params.accept_events = true;
+  params.accept_events = false;
   params.parent = window_->parent();
   minimized_widget_ = std::make_unique<views::Widget>();
   minimized_widget_->set_focus_on_creation(false);
@@ -711,7 +585,6 @@ void ScopedTransformOverviewWindow::CreateMirrorWindowForMinimizedState() {
   views::View* mirror_view =
       new wm::WindowMirrorView(window_, /*trilinear_filtering_on_init=*/false);
   mirror_view->SetVisible(true);
-  mirror_view->SetTargetHandler(this);
   minimized_widget_->SetContentsView(mirror_view);
   gfx::Rect bounds(window_->GetBoundsInScreen());
   gfx::Size preferred = mirror_view->GetPreferredSize();
