@@ -13,6 +13,7 @@
 
 #include "ash/public/cpp/shelf_types.h"
 #include "ash/public/cpp/shell_window_ids.h"
+#include "ash/public/cpp/window_state_type.h"
 #include "ash/root_window_controller.h"
 #include "ash/screen_util.h"
 #include "ash/shelf/shelf.h"
@@ -22,6 +23,7 @@
 #include "ash/wallpaper/wallpaper_widget_controller.h"
 #include "ash/wm/overview/cleanup_animation_observer.h"
 #include "ash/wm/overview/overview_utils.h"
+#include "ash/wm/overview/overview_window_animation_observer.h"
 #include "ash/wm/overview/rounded_rect_view.h"
 #include "ash/wm/overview/scoped_overview_animation_settings.h"
 #include "ash/wm/overview/window_selector.h"
@@ -31,27 +33,20 @@
 #include "base/i18n/string_search.h"
 #include "base/strings/string_number_conversions.h"
 #include "third_party/skia/include/core/SkColor.h"
-#include "third_party/skia/include/pathops/SkPathOps.h"
+#include "ui/aura/client/aura_constants.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/compositor/layer_animation_observer.h"
 #include "ui/compositor/scoped_layer_animation_settings.h"
 #include "ui/gfx/animation/tween.h"
-#include "ui/gfx/canvas.h"
 #include "ui/gfx/color_analysis.h"
 #include "ui/gfx/color_utils.h"
 #include "ui/gfx/geometry/safe_integer_conversions.h"
 #include "ui/gfx/geometry/vector2d.h"
-#include "ui/gfx/scoped_canvas.h"
-#include "ui/views/background.h"
-#include "ui/views/border.h"
 #include "ui/views/layout/box_layout.h"
-#include "ui/views/painter.h"
 #include "ui/views/view.h"
 #include "ui/views/widget/widget.h"
 #include "ui/wm/core/coordinate_conversion.h"
 #include "ui/wm/core/shadow.h"
-#include "ui/wm/core/shadow_types.h"
-#include "ui/wm/core/window_animations.h"
 
 namespace ash {
 namespace {
@@ -73,8 +68,9 @@ constexpr SkColor kWindowSelectionBorderColor =
 // Border thickness of overview selector.
 constexpr int kWindowSelectionBorderThickness = 1;
 
-// Corner radius of the overview selector border.
+// Corner radius and shadow applied to the overview selector border.
 constexpr int kWindowSelectionRadius = 9;
+constexpr int kWindowSelectionShadowElevation = 24;
 
 // Values for the old overview ui.
 // TODO(crbug.com/782320): Delete these values when the old ui becomes obsolete.
@@ -114,69 +110,6 @@ constexpr SkColor kNoItemsIndicatorBackgroundColor = SK_ColorBLACK;
 constexpr SkColor kNoItemsIndicatorTextColor = SK_ColorWHITE;
 constexpr float kNoItemsIndicatorBackgroundOpacity = 0.8f;
 
-// BackgroundWith1PxBorder renders a solid background color, with a one pixel
-// border with rounded corners. This accounts for the scaling of the canvas, so
-// that the border is 1 pixel thick regardless of display scaling.
-class BackgroundWith1PxBorder : public views::Background {
- public:
-  BackgroundWith1PxBorder(SkColor background,
-                          SkColor border_color,
-                          int border_thickness,
-                          int corner_radius)
-      : border_color_(border_color),
-        border_thickness_(border_thickness),
-        corner_radius_(corner_radius) {
-    SetNativeControlColor(background);
-  }
-
-  // views::Background:
-  void Paint(gfx::Canvas* canvas, views::View* view) const override {
-    gfx::RectF border_rect_f(view->GetContentsBounds());
-
-    gfx::ScopedCanvas scoped_canvas(canvas);
-    const float scale = canvas->UndoDeviceScaleFactor();
-    border_rect_f.Inset(border_thickness_, border_thickness_);
-    border_rect_f = gfx::ScaleRect(border_rect_f, scale);
-
-    SkPath path;
-    const SkScalar scaled_corner_radius =
-        SkFloatToScalar(corner_radius_ * scale + 0.5f);
-    path.addRoundRect(gfx::RectFToSkRect(border_rect_f), scaled_corner_radius,
-                      scaled_corner_radius);
-
-    cc::PaintFlags flags;
-    flags.setStyle(cc::PaintFlags::kStroke_Style);
-    flags.setStrokeWidth(1);
-    flags.setAntiAlias(true);
-
-    SkPath stroke_path;
-    flags.getFillPath(path, &stroke_path);
-
-    SkPath fill_path;
-    Op(path, stroke_path, kDifference_SkPathOp, &fill_path);
-    flags.setStyle(cc::PaintFlags::kFill_Style);
-    flags.setColor(get_color());
-    canvas->sk_canvas()->drawPath(fill_path, flags);
-
-    if (border_thickness_ > 0) {
-      flags.setColor(border_color_);
-      canvas->sk_canvas()->drawPath(stroke_path, flags);
-    }
-  }
-
- private:
-  // Color for the one pixel border.
-  SkColor border_color_;
-
-  // Thickness of border inset.
-  int border_thickness_;
-
-  // Corner radius of the inside edge of the roundrect border stroke.
-  int corner_radius_;
-
-  DISALLOW_COPY_AND_ASSIGN(BackgroundWith1PxBorder);
-};
-
 // Returns the vector for the fade in animation.
 gfx::Vector2d GetSlideVectorForFadeIn(WindowSelector::Direction direction,
                                       const gfx::Rect& bounds) {
@@ -194,58 +127,6 @@ gfx::Vector2d GetSlideVectorForFadeIn(WindowSelector::Direction direction,
   return vector;
 }
 
-// Creates and returns a background translucent widget parented in
-// |root_window|'s default container and having |background_color|.
-// When |border_thickness| is non-zero, a border is created having
-// |border_color|, otherwise |border_color| parameter is ignored.
-// The new background widget starts with |initial_opacity| and then fades in.
-views::Widget* CreateBackgroundWidget(aura::Window* root_window,
-                                      ui::LayerType layer_type,
-                                      SkColor background_color,
-                                      int border_thickness,
-                                      int border_radius,
-                                      SkColor border_color,
-                                      float initial_opacity) {
-  views::Widget* widget = new views::Widget;
-  views::Widget::InitParams params;
-  params.type = views::Widget::InitParams::TYPE_POPUP;
-  params.keep_on_top = false;
-  params.ownership = views::Widget::InitParams::WIDGET_OWNS_NATIVE_WIDGET;
-  params.opacity = views::Widget::InitParams::TRANSLUCENT_WINDOW;
-  params.layer_type = layer_type;
-  params.accept_events = false;
-  widget->set_focus_on_creation(false);
-  // Parenting in kShellWindowId_WallpaperContainer allows proper layering of
-  // the shield and selection widgets. Since that container is created with
-  // USE_LOCAL_COORDINATES BoundsInScreenBehavior local bounds in |root_window_|
-  // need to be provided.
-  params.parent = root_window->GetChildById(kShellWindowId_WallpaperContainer);
-  widget->Init(params);
-  aura::Window* widget_window = widget->GetNativeWindow();
-  // Disable the "bounce in" animation when showing the window.
-  ::wm::SetWindowVisibilityAnimationTransition(widget_window,
-                                               ::wm::ANIMATE_NONE);
-  // The background widget should not activate the shelf when passing under it.
-  wm::GetWindowState(widget_window)->set_ignored_by_shelf(true);
-  if (params.layer_type == ui::LAYER_SOLID_COLOR) {
-    widget_window->layer()->SetColor(background_color);
-  } else {
-    views::View* content_view =
-        new RoundedRectView(border_radius, SK_ColorTRANSPARENT);
-    content_view->SetBackground(std::make_unique<BackgroundWith1PxBorder>(
-        background_color, border_color, border_thickness, border_radius));
-    widget->SetContentsView(content_view);
-  }
-  widget_window->parent()->StackChildAtTop(widget_window);
-  widget->Show();
-  widget_window->layer()->SetOpacity(initial_opacity);
-  return widget;
-}
-
-bool IsMinimizedStateType(mojom::WindowStateType type) {
-  return type == mojom::WindowStateType::MINIMIZED;
-}
-
 }  // namespace
 
 // ShieldView contains the background for overview mode. It also contains text
@@ -335,6 +216,17 @@ WindowGrid::WindowGrid(aura::Window* root_window,
   }
 
   for (auto* window : windows_in_root) {
+    // TODO(https://crbug.com/812496): Investigate why we need to keep target
+    // transform instead of using identity when exiting.
+    // Stop ongoing animations before entering overview mode. Because we are
+    // deferring SetTransform of the windows beneath the window covering the
+    // available workspace, we need to set the correct transforms of these
+    // windows before entering overview mode again in the
+    // OnImplicitAnimationsCompleted() of the observer of the
+    // available-workspace-covering window's animation.
+    auto* animator = window->layer()->GetAnimator();
+    if (animator->is_animating())
+      window->layer()->GetAnimator()->StopAnimating();
     window_observer_.Add(window);
     window_state_observer_.Add(wm::GetWindowState(window));
     window_list_.push_back(
@@ -397,7 +289,7 @@ void WindowGrid::PrepareForOverview() {
 
 void WindowGrid::PositionWindows(bool animate,
                                  WindowSelectorItem* ignored_item) {
-  if (window_selector_->is_shut_down() || window_list_.empty())
+  if (window_selector_->IsShuttingDown() || window_list_.empty())
     return;
   DCHECK(shield_widget_.get());
   // Keep the background shield widget covering the whole screen.
@@ -519,9 +411,11 @@ void WindowGrid::PositionWindows(bool animate,
       --j;
       continue;
     }
+
+    const bool should_animate = window_list_[i]->ShouldAnimateWhenEntering();
     window_list_[i]->SetBounds(
         rects[j] + offset,
-        animate
+        animate && should_animate
             ? OverviewAnimationType::OVERVIEW_ANIMATION_LAY_OUT_SELECTOR_ITEMS
             : OverviewAnimationType::OVERVIEW_ANIMATION_NONE);
   }
@@ -598,16 +492,17 @@ WindowSelectorItem* WindowGrid::SelectedWindow() const {
   return window_list_[selected_index_].get();
 }
 
-bool WindowGrid::Contains(const aura::Window* window) const {
+WindowSelectorItem* WindowGrid::GetWindowSelectorItemContaining(
+    const aura::Window* window) const {
   for (const auto& window_item : window_list_) {
     if (window_item->Contains(window))
-      return true;
+      return window_item.get();
   }
-  return false;
+  return nullptr;
 }
 
 void WindowGrid::AddItem(aura::Window* window) {
-  DCHECK(!Contains(window));
+  DCHECK(!GetWindowSelectorItemContaining(window));
 
   window_observer_.Add(window);
   window_state_observer_.Add(wm::GetWindowState(window));
@@ -685,6 +580,16 @@ void WindowGrid::UpdateCannotSnapWarningVisibility() {
     window_selector_item->UpdateCannotSnapWarningVisibility();
 }
 
+void WindowGrid::OnSelectorItemDragStarted(WindowSelectorItem* item) {
+  for (auto& window_selector_item : window_list_)
+    window_selector_item->OnSelectorItemDragStarted(item);
+}
+
+void WindowGrid::OnSelectorItemDragEnded() {
+  for (auto& window_selector_item : window_list_)
+    window_selector_item->OnSelectorItemDragEnded();
+}
+
 void WindowGrid::OnWindowDestroying(aura::Window* window) {
   window_observer_.Remove(window);
   window_state_observer_.Remove(wm::GetWindowState(window));
@@ -747,8 +652,10 @@ void WindowGrid::OnPostWindowStateTypeChange(wm::WindowState* window_state,
     return;
 
   mojom::WindowStateType new_type = window_state->GetStateType();
-  if (IsMinimizedStateType(old_type) == IsMinimizedStateType(new_type))
+  if (IsMinimizedWindowStateType(old_type) ==
+      IsMinimizedWindowStateType(new_type)) {
     return;
+  }
 
   auto iter =
       std::find_if(window_list_.begin(), window_list_.end(),
@@ -765,6 +672,63 @@ bool WindowGrid::IsNoItemsIndicatorLabelVisibleForTesting() {
   return shield_view_ && shield_view_->IsLabelVisible();
 }
 
+void WindowGrid::SetWindowListAnimationStates(
+    WindowSelectorItem* selected_item,
+    WindowSelector::OverviewTransition transition) {
+  // |selected_item| is nullptr during entering animation.
+  DCHECK(transition == WindowSelector::OverviewTransition::kExit ||
+         selected_item == nullptr);
+
+  bool has_covered_available_workspace = false;
+  bool has_checked_selected_item = false;
+  if (!selected_item ||
+      !wm::GetWindowState(selected_item->GetWindow())->IsFullscreen()) {
+    // Check the always on top window first if |selected_item| is nullptr or the
+    // |selected_item|'s window is not fullscreen. Because always on top windows
+    // are visible and may have a window which can cover available workspace.
+    // If the |selected_item| is fullscreen, we will depromote all always on top
+    // windows.
+    aura::Window* always_on_top_container =
+        RootWindowController::ForWindow(root_window_)
+            ->GetContainer(kShellWindowId_AlwaysOnTopContainer);
+    aura::Window::Windows top_windows = always_on_top_container->children();
+    for (aura::Window::Windows::const_reverse_iterator
+             it = top_windows.rbegin(),
+             rend = top_windows.rend();
+         it != rend; ++it) {
+      aura::Window* top_window = *it;
+      WindowSelectorItem* container_item =
+          GetWindowSelectorItemContaining(top_window);
+      if (!container_item)
+        continue;
+
+      const bool is_selected_item = (selected_item == container_item);
+      if (!has_checked_selected_item && is_selected_item)
+        has_checked_selected_item = true;
+      SetWindowSelectorItemAnimationState(
+          container_item, &has_covered_available_workspace,
+          /*selected=*/is_selected_item, transition);
+    }
+  }
+
+  if (!has_checked_selected_item) {
+    SetWindowSelectorItemAnimationState(selected_item,
+                                        &has_covered_available_workspace,
+                                        /*selected=*/true, transition);
+  }
+  for (const auto& item : window_list_) {
+    // Has checked the |selected_item|.
+    if (selected_item == item.get())
+      continue;
+    // Has checked all always on top windows.
+    if (item->GetWindow()->GetProperty(aura::client::kAlwaysOnTopKey))
+      continue;
+    SetWindowSelectorItemAnimationState(item.get(),
+                                        &has_covered_available_workspace,
+                                        /*selected=*/false, transition);
+  }
+}
+
 void WindowGrid::InitShieldWidget() {
   // TODO(varkha): The code assumes that SHELF_BACKGROUND_MAXIMIZED is
   // synonymous with a black shelf background. Update this code if that
@@ -787,10 +751,11 @@ void WindowGrid::InitShieldWidget() {
                                                          dark_muted_color);
     }
   }
-  shield_widget_.reset(CreateBackgroundWidget(
+  shield_widget_ = CreateBackgroundWidget(
       root_window_, ui::LAYER_SOLID_COLOR,
       IsNewOverviewUi() ? SK_ColorTRANSPARENT : shield_color, 0, 0,
-      SK_ColorTRANSPARENT, initial_opacity));
+      SK_ColorTRANSPARENT, initial_opacity, /*parent=*/nullptr,
+      /*stack_on_top=*/true);
   aura::Window* widget_window = shield_widget_->GetNativeWindow();
   const gfx::Rect bounds = widget_window->parent()->bounds();
   widget_window->SetBounds(bounds);
@@ -816,14 +781,16 @@ void WindowGrid::InitShieldWidget() {
 
 void WindowGrid::InitSelectionWidget(WindowSelector::Direction direction) {
   if (IsNewOverviewUi()) {
-    selection_widget_.reset(CreateBackgroundWidget(
+    selection_widget_ = CreateBackgroundWidget(
         root_window_, ui::LAYER_TEXTURED, kWindowSelectionColor, 0,
-        kWindowSelectionRadius, SK_ColorTRANSPARENT, 0.f));
+        kWindowSelectionRadius, SK_ColorTRANSPARENT, 0.f, /*parent=*/nullptr,
+        /*stack_on_top=*/true);
   } else {
-    selection_widget_.reset(CreateBackgroundWidget(
+    selection_widget_ = CreateBackgroundWidget(
         root_window_, ui::LAYER_TEXTURED, kOldWindowSelectionColor,
         kWindowSelectionBorderThickness, kOldWindowSelectionRadius,
-        kWindowSelectionBorderColor, 0.f));
+        kWindowSelectionBorderColor, 0.f, /*parent=*/nullptr,
+        /*stack_on_top=*/true);
   }
   aura::Window* widget_window = selection_widget_->GetNativeWindow();
   gfx::Rect target_bounds = SelectedWindow()->target_bounds();
@@ -833,8 +800,8 @@ void WindowGrid::InitSelectionWidget(WindowSelector::Direction direction) {
   widget_window->SetBounds(target_bounds - fade_out_direction);
   widget_window->SetName("OverviewModeSelector");
 
-  selector_shadow_.reset(new ::wm::Shadow());
-  selector_shadow_->Init(::wm::ShadowElevation::LARGE);
+  selector_shadow_ = std::make_unique<::wm::Shadow>();
+  selector_shadow_->Init(kWindowSelectionShadowElevation);
   selector_shadow_->layer()->SetVisible(true);
   selection_widget_->GetLayer()->SetMasksToBounds(false);
   selection_widget_->GetLayer()->Add(selector_shadow_->layer());
@@ -1008,4 +975,33 @@ bool WindowGrid::FitWindowRectsInBounds(const gfx::Rect& bounds,
   return windows_fit;
 }
 
+void WindowGrid::SetWindowSelectorItemAnimationState(
+    WindowSelectorItem* selector_item,
+    bool* has_covered_available_workspace,
+    bool selected,
+    WindowSelector::OverviewTransition transition) {
+  if (!selector_item)
+    return;
+
+  aura::Window* window = selector_item->GetWindow();
+  // |selector_item| should be contained in the |window_list_|.
+  DCHECK(GetWindowSelectorItemContaining(window));
+
+  bool can_cover_available_workspace = CanCoverAvailableWorkspace(window);
+  const bool should_animate = selected || !(*has_covered_available_workspace);
+  if (transition == WindowSelector::OverviewTransition::kEnter)
+    selector_item->set_should_animate_when_entering(should_animate);
+  if (transition == WindowSelector::OverviewTransition::kExit)
+    selector_item->set_should_animate_when_exiting(should_animate);
+
+  if (!(*has_covered_available_workspace) && can_cover_available_workspace) {
+    if (transition == WindowSelector::OverviewTransition::kExit) {
+      selector_item->set_should_be_observed_when_exiting(true);
+      auto* observer = new OverviewWindowAnimationObserver();
+      set_window_animation_observer(observer->GetWeakPtr());
+    }
+    *has_covered_available_workspace = true;
+  }
+}
+
 }  // namespace ash
