@@ -26,6 +26,7 @@
 #include "base/compiler_specific.h"
 #include "base/i18n/rtl.h"
 #include "base/run_loop.h"
+#include "base/stl_util.h"
 #include "base/strings/string_number_conversions.h"
 #include "ui/aura/client/aura_constants.h"
 #include "ui/aura/test/test_windows.h"
@@ -469,15 +470,11 @@ TEST_F(PanelLayoutManagerTest, MultiplePanelStackingVertical) {
   wm::ActivateWindow(w1.get());
   shelf_view_test()->RunMessageLoopUntilAnimationsDone();
   EXPECT_TRUE(WindowIsAbove(w1.get(), w2.get()));
-  // TODO(crbug.com/698887): investigate failure in Mash.
-  if (Shell::GetAshConfig() != Config::MASH)
-    EXPECT_TRUE(WindowIsAbove(w2.get(), w3.get()));
+  EXPECT_TRUE(WindowIsAbove(w2.get(), w3.get()));
 
   wm::ActivateWindow(w2.get());
   shelf_view_test()->RunMessageLoopUntilAnimationsDone();
-  // TODO(crbug.com/698887): investigate failure in Mash.
-  if (Shell::GetAshConfig() != Config::MASH)
-    EXPECT_TRUE(WindowIsAbove(w1.get(), w3.get()));
+  EXPECT_TRUE(WindowIsAbove(w1.get(), w3.get()));
   EXPECT_TRUE(WindowIsAbove(w2.get(), w3.get()));
   EXPECT_TRUE(WindowIsAbove(w2.get(), w1.get()));
 
@@ -497,10 +494,6 @@ TEST_F(PanelLayoutManagerTest, MultiplePanelCallout) {
   EXPECT_TRUE(IsPanelCalloutVisible(w2.get()));
   EXPECT_TRUE(IsPanelCalloutVisible(w3.get()));
 
-  // TODO(crbug.com/698887): investigate failure in Mash.
-  if (Shell::GetAshConfig() == Config::MASH)
-    return;
-
   wm::ActivateWindow(w1.get());
   EXPECT_NO_FATAL_FAILURE(IsCalloutAboveLauncherIcon(w1.get()));
   wm::ActivateWindow(w2.get());
@@ -606,9 +599,7 @@ TEST_F(PanelLayoutManagerTest, FanWindows) {
   Shelf* shelf = GetPrimaryShelf();
   int icon_x1 = shelf->GetScreenBoundsOfItemIconForWindow(w1.get()).x();
   int icon_x2 = shelf->GetScreenBoundsOfItemIconForWindow(w2.get()).x();
-  // TODO(crbug.com/698887): investigate failure in Mash.
-  if (Shell::GetAshConfig() != Config::MASH)
-    EXPECT_EQ(window_x2 - window_x1, window_x3 - window_x2);
+  EXPECT_EQ(window_x2 - window_x1, window_x3 - window_x2);
   // New shelf items for panels are inserted before existing panel items.
   EXPECT_LT(window_x2, window_x1);
   EXPECT_LT(window_x3, window_x2);
@@ -823,15 +814,9 @@ TEST_F(PanelLayoutManagerTest, PanelsHideAndRestoreWithShelf) {
   aura::Window::Windows switchable_window_list =
       Shell::Get()->mru_window_tracker()->BuildMruWindowList();
   EXPECT_EQ(3u, switchable_window_list.size());
-  EXPECT_NE(switchable_window_list.end(),
-            std::find(switchable_window_list.begin(),
-                      switchable_window_list.end(), w1.get()));
-  EXPECT_NE(switchable_window_list.end(),
-            std::find(switchable_window_list.begin(),
-                      switchable_window_list.end(), w2.get()));
-  EXPECT_NE(switchable_window_list.end(),
-            std::find(switchable_window_list.begin(),
-                      switchable_window_list.end(), w3.get()));
+  EXPECT_TRUE(base::ContainsValue(switchable_window_list, w1.get()));
+  EXPECT_TRUE(base::ContainsValue(switchable_window_list, w2.get()));
+  EXPECT_TRUE(base::ContainsValue(switchable_window_list, w3.get()));
 
   SetShelfVisibilityState(Shell::GetPrimaryRootWindow(), SHELF_VISIBLE);
   RunAllPendingInMessageLoop();
