@@ -15,6 +15,7 @@
 #include "ash/wm/overview/window_selector_controller.h"
 #include "base/command_line.h"
 #include "base/run_loop.h"
+#include "base/test/histogram_tester.h"
 #include "base/test/simple_test_tick_clock.h"
 #include "base/test/user_action_tester.h"
 #include "chromeos/accelerometer/accelerometer_reader.h"
@@ -120,15 +121,12 @@ class TabletModeControllerTest : public AshTestBase {
   // Attaches a SimpleTestTickClock to the TabletModeController with a non
   // null value initial value.
   void AttachTickClockForTest() {
-    std::unique_ptr<base::TickClock> tick_clock(
-        test_tick_clock_ = new base::SimpleTestTickClock());
-    test_tick_clock_->Advance(base::TimeDelta::FromSeconds(1));
-    tablet_mode_controller()->SetTickClockForTest(std::move(tick_clock));
+    test_tick_clock_.Advance(base::TimeDelta::FromSeconds(1));
+    tablet_mode_controller()->SetTickClockForTest(&test_tick_clock_);
   }
 
   void AdvanceTickClock(const base::TimeDelta& delta) {
-    DCHECK(test_tick_clock_);
-    test_tick_clock_->Advance(delta);
+    test_tick_clock_.Advance(delta);
   }
 
   void OpenLidToAngle(float degrees) {
@@ -160,8 +158,8 @@ class TabletModeControllerTest : public AshTestBase {
         tablet_mode_controller()->tick_clock_->NowTicks());
   }
 
-  bool WasLidOpenedRecently() {
-    return tablet_mode_controller()->WasLidOpenedRecently();
+  bool CanUseUnstableLidAngle() {
+    return tablet_mode_controller()->CanUseUnstableLidAngle();
   }
 
   void SetTabletMode(bool on) {
@@ -182,7 +180,7 @@ class TabletModeControllerTest : public AshTestBase {
   base::UserActionTester* user_action_tester() { return &user_action_tester_; }
 
  private:
-  base::SimpleTestTickClock* test_tick_clock_;
+  base::SimpleTestTickClock test_tick_clock_;
 
   // Tracks user action counts.
   base::UserActionTester user_action_tester_;
@@ -239,49 +237,40 @@ TEST_F(TabletModeControllerTest, HingeAnglesWithLidClosed) {
   EXPECT_FALSE(IsTabletModeStarted());
 }
 
-// Verify the tablet mode state for unstable hinge angles when the lid was
-// recently open.
-TEST_F(TabletModeControllerTest, UnstableHingeAnglesWhenLidRecentlyOpened) {
+// Verify the unstable lid angle is suppressed during opening the lid.
+TEST_F(TabletModeControllerTest, OpenLidUnstableLidAngle) {
   AttachTickClockForTest();
 
   OpenLid();
-  ASSERT_TRUE(WasLidOpenedRecently());
 
+  // Simulate the erroneous accelerometer readings.
+  OpenLidToAngle(355.0f);
+  EXPECT_FALSE(IsTabletModeStarted());
+
+  // Simulate the correct accelerometer readings.
+  OpenLidToAngle(5.0f);
+  EXPECT_FALSE(IsTabletModeStarted());
+}
+
+// Verify the unstable lid angle is suppressed during closing the lid.
+TEST_F(TabletModeControllerTest, CloseLidUnstableLidAngle) {
+  AttachTickClockForTest();
+
+  OpenLid();
+
+  OpenLidToAngle(45.0f);
+  EXPECT_FALSE(IsTabletModeStarted());
+
+  // Simulate the correct accelerometer readings.
   OpenLidToAngle(5.0f);
   EXPECT_FALSE(IsTabletModeStarted());
 
+  // Simulate the erroneous accelerometer readings.
   OpenLidToAngle(355.0f);
   EXPECT_FALSE(IsTabletModeStarted());
 
-  // This is a stable reading and should clear the last lid opened time.
-  OpenLidToAngle(45.0f);
-  EXPECT_FALSE(IsTabletModeStarted());
-  EXPECT_FALSE(WasLidOpenedRecently());
-
-  OpenLidToAngle(355.0f);
-  EXPECT_TRUE(IsTabletModeStarted());
-}
-
-// Verify the WasLidOpenedRecently signal with respect to time.
-TEST_F(TabletModeControllerTest, WasLidOpenedRecentlyOverTime) {
-  AttachTickClockForTest();
-
-  // No lid open time initially.
-  ASSERT_FALSE(WasLidOpenedRecently());
-
   CloseLid();
-  EXPECT_FALSE(WasLidOpenedRecently());
-
-  OpenLid();
-  EXPECT_TRUE(WasLidOpenedRecently());
-
-  // 1 second after lid open.
-  AdvanceTickClock(base::TimeDelta::FromSeconds(1));
-  EXPECT_TRUE(WasLidOpenedRecently());
-
-  // 3 seconds after lid open.
-  AdvanceTickClock(base::TimeDelta::FromSeconds(2));
-  EXPECT_FALSE(WasLidOpenedRecently());
+  EXPECT_FALSE(IsTabletModeStarted());
 }
 
 TEST_F(TabletModeControllerTest, TabletModeTransition) {
@@ -333,7 +322,6 @@ TEST_F(TabletModeControllerTest, TabletModeTransitionNoKeyboardAccelerometer) {
 // Verify the tablet mode enter/exit thresholds for stable angles.
 TEST_F(TabletModeControllerTest, StableHingeAnglesWithLidOpened) {
   ASSERT_FALSE(IsTabletModeStarted());
-  ASSERT_FALSE(WasLidOpenedRecently());
 
   OpenLidToAngle(180.0f);
   EXPECT_FALSE(IsTabletModeStarted());
@@ -354,20 +342,59 @@ TEST_F(TabletModeControllerTest, StableHingeAnglesWithLidOpened) {
   EXPECT_FALSE(IsTabletModeStarted());
 }
 
-// Verify the tablet mode state for unstable hinge angles when the lid is open
-// but not recently.
-TEST_F(TabletModeControllerTest, UnstableHingeAnglesWithLidOpened) {
+// Verify entering tablet mode for unstable lid angles when a certain range of
+// time has passed.
+TEST_F(TabletModeControllerTest, EnterTabletModeWithUnstableLidAngle) {
   AttachTickClockForTest();
 
-  ASSERT_FALSE(WasLidOpenedRecently());
+  OpenLid();
+
   ASSERT_FALSE(IsTabletModeStarted());
 
   OpenLidToAngle(5.0f);
   EXPECT_FALSE(IsTabletModeStarted());
 
+  EXPECT_FALSE(CanUseUnstableLidAngle());
+  OpenLidToAngle(355.0f);
+  EXPECT_FALSE(IsTabletModeStarted());
+
+  // 1 second after entering unstable angle zone.
+  AdvanceTickClock(base::TimeDelta::FromSeconds(1));
+  EXPECT_FALSE(CanUseUnstableLidAngle());
+  OpenLidToAngle(355.0f);
+  EXPECT_FALSE(IsTabletModeStarted());
+
+  // 2 seconds after entering unstable angle zone.
+  AdvanceTickClock(base::TimeDelta::FromSeconds(1));
+  EXPECT_TRUE(CanUseUnstableLidAngle());
   OpenLidToAngle(355.0f);
   EXPECT_TRUE(IsTabletModeStarted());
+}
 
+// Verify not exiting tablet mode for unstable lid angles even after a certain
+// range of time has passed.
+TEST_F(TabletModeControllerTest, NotExitTabletModeWithUnstableLidAngle) {
+  AttachTickClockForTest();
+
+  OpenLid();
+
+  ASSERT_FALSE(IsTabletModeStarted());
+
+  OpenLidToAngle(280.0f);
+  EXPECT_TRUE(IsTabletModeStarted());
+
+  OpenLidToAngle(5.0f);
+  EXPECT_TRUE(IsTabletModeStarted());
+
+  // 1 second after entering unstable angle zone.
+  AdvanceTickClock(base::TimeDelta::FromSeconds(1));
+  EXPECT_FALSE(CanUseUnstableLidAngle());
+  OpenLidToAngle(5.0f);
+  EXPECT_TRUE(IsTabletModeStarted());
+
+  // 2 seconds after entering unstable angle zone.
+  AdvanceTickClock(base::TimeDelta::FromSeconds(1));
+  EXPECT_TRUE(CanUseUnstableLidAngle());
   OpenLidToAngle(5.0f);
   EXPECT_TRUE(IsTabletModeStarted());
 }
@@ -660,4 +687,39 @@ TEST_F(TabletModeControllerTest, RestoreAfterExit) {
   EXPECT_EQ(gfx::Rect(10, 10, 900, 300), w1->bounds());
 }
 
+TEST_F(TabletModeControllerTest, RecordLidAngle) {
+  // The timer shouldn't be running before we've received accelerometer data.
+  EXPECT_FALSE(
+      tablet_mode_controller()->TriggerRecordLidAngleTimerForTesting());
+
+  base::HistogramTester histogram_tester;
+  OpenLidToAngle(300.0f);
+  ASSERT_TRUE(tablet_mode_controller()->TriggerRecordLidAngleTimerForTesting());
+  histogram_tester.ExpectBucketCount(
+      TabletModeController::kLidAngleHistogramName, 300, 1);
+
+  ASSERT_TRUE(tablet_mode_controller()->TriggerRecordLidAngleTimerForTesting());
+  histogram_tester.ExpectBucketCount(
+      TabletModeController::kLidAngleHistogramName, 300, 2);
+
+  OpenLidToAngle(90.0f);
+  ASSERT_TRUE(tablet_mode_controller()->TriggerRecordLidAngleTimerForTesting());
+  histogram_tester.ExpectBucketCount(
+      TabletModeController::kLidAngleHistogramName, 90, 1);
+
+  // The timer should be stopped in response to a lid-only update since we can
+  // no longer compute an angle.
+  TriggerLidUpdate(gfx::Vector3dF(0.0f, 0.0f, kMeanGravity));
+  EXPECT_FALSE(
+      tablet_mode_controller()->TriggerRecordLidAngleTimerForTesting());
+  histogram_tester.ExpectTotalCount(
+      TabletModeController::kLidAngleHistogramName, 3);
+
+  // When lid and base data is received, the timer should be started again.
+  OpenLidToAngle(180.0f);
+  ASSERT_TRUE(tablet_mode_controller()->TriggerRecordLidAngleTimerForTesting());
+  histogram_tester.ExpectBucketCount(
+      TabletModeController::kLidAngleHistogramName, 180, 1);
+}
+
 }  // namespace ash
