@@ -8,6 +8,8 @@
 
 #include "ash/public/cpp/ash_switches.h"
 #include "ash/public/cpp/shelf_prefs.h"
+#include "ash/public/cpp/window_properties.h"
+#include "ash/public/cpp/window_state_type.h"
 #include "ash/root_window_controller.h"
 #include "ash/screen_util.h"
 #include "ash/session/session_controller.h"
@@ -21,6 +23,7 @@
 #include "ash/wm/switchable_windows.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "ash/wm/window_properties.h"
+#include "ash/wm/window_resizer.h"
 #include "ash/wm/window_state.h"
 #include "ash/wm/window_state_observer.h"
 #include "ash/wm/window_util.h"
@@ -548,8 +551,8 @@ std::string GetPlacementOverride(aura::Window* window) {
   gfx::Rect* bounds = window->GetProperty(kRestoreBoundsOverrideKey);
   if (bounds) {
     gfx::Rect restore_bounds = *bounds;
-    ui::WindowShowState restore_state =
-        window->GetProperty(kRestoreShowStateOverrideKey);
+    ui::WindowShowState restore_state = ToWindowShowState(
+        window->GetProperty(kRestoreWindowStateTypeOverrideKey));
     return GetPlacementString(restore_bounds, restore_state);
   }
   return std::string();
@@ -881,6 +884,26 @@ TEST_F(TabletModeWindowManagerTest, TestMinimize) {
   EXPECT_TRUE(window->IsVisible());
 }
 
+// Tests that minimized window can restore to pre-minimized show state after
+// entering and leaving tablet mode (https://crbug.com/783310).
+TEST_F(TabletModeWindowManagerTest, MinimizedEnterAndLeaveTabletMode) {
+  gfx::Rect rect(10, 10, 100, 100);
+  std::unique_ptr<aura::Window> window(
+      CreateWindow(aura::client::WINDOW_TYPE_NORMAL, rect));
+  wm::WindowState* window_state = wm::GetWindowState(window.get());
+  window_state->Minimize();
+  EXPECT_TRUE(window_state->IsMinimized());
+  Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(true);
+  EXPECT_TRUE(window_state->IsMinimized());
+  Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(false);
+  EXPECT_TRUE(window_state->IsMinimized());
+
+  window_state->Unminimize();
+  EXPECT_FALSE(window_state->IsMinimized());
+  window_state->Minimize();
+  EXPECT_TRUE(window_state->IsMinimized());
+}
+
 // Check that a full screen window remains full screen upon entering maximize
 // mode. Furthermore, checks that this window is not full screen upon exiting
 // tablet mode if it was un-full-screened while in tablet mode.
@@ -1515,8 +1538,6 @@ TEST_F(TabletModeWindowManagerTest, AlwaysOnTopWindows) {
   EXPECT_FALSE(wm::GetWindowState(w2.get())->IsMaximized());
   EXPECT_EQ(rect1.ToString(), w1->bounds().ToString());
   EXPECT_EQ(rect2.ToString(), w2->bounds().ToString());
-  EXPECT_TRUE(wm::GetWindowState(w1.get())->can_be_dragged());
-  EXPECT_TRUE(wm::GetWindowState(w2.get())->can_be_dragged());
 
   // Enter tablet mode. Neither window should be managed because they have
   // the always-on-top property set, which means that none of their properties
@@ -1528,8 +1549,6 @@ TEST_F(TabletModeWindowManagerTest, AlwaysOnTopWindows) {
   EXPECT_FALSE(wm::GetWindowState(w2.get())->IsMaximized());
   EXPECT_EQ(rect1.ToString(), w1->bounds().ToString());
   EXPECT_EQ(rect2.ToString(), w2->bounds().ToString());
-  EXPECT_TRUE(wm::GetWindowState(w1.get())->can_be_dragged());
-  EXPECT_TRUE(wm::GetWindowState(w2.get())->can_be_dragged());
 
   // Remove the always-on-top property from both windows while in maximize
   // mode. The windows should become managed, which means they should be
@@ -1543,8 +1562,6 @@ TEST_F(TabletModeWindowManagerTest, AlwaysOnTopWindows) {
   EXPECT_NE(rect1.size().ToString(), w1->bounds().size().ToString());
   EXPECT_NE(rect2.origin().ToString(), w2->bounds().origin().ToString());
   EXPECT_EQ(rect2.size().ToString(), w2->bounds().size().ToString());
-  EXPECT_FALSE(wm::GetWindowState(w1.get())->can_be_dragged());
-  EXPECT_FALSE(wm::GetWindowState(w2.get())->can_be_dragged());
 
   // Applying the always-on-top property to both windows while in maximize
   // mode should cause both windows to return to their original size,
@@ -1556,8 +1573,6 @@ TEST_F(TabletModeWindowManagerTest, AlwaysOnTopWindows) {
   EXPECT_FALSE(wm::GetWindowState(w2.get())->IsMaximized());
   EXPECT_EQ(rect1.ToString(), w1->bounds().ToString());
   EXPECT_EQ(rect2.ToString(), w2->bounds().ToString());
-  EXPECT_TRUE(wm::GetWindowState(w1.get())->can_be_dragged());
-  EXPECT_TRUE(wm::GetWindowState(w2.get())->can_be_dragged());
 
   // The always-on-top windows should not change when leaving tablet mode.
   DestroyTabletModeWindowManager();
@@ -1565,8 +1580,6 @@ TEST_F(TabletModeWindowManagerTest, AlwaysOnTopWindows) {
   EXPECT_FALSE(wm::GetWindowState(w2.get())->IsMaximized());
   EXPECT_EQ(rect1.ToString(), w1->bounds().ToString());
   EXPECT_EQ(rect2.ToString(), w2->bounds().ToString());
-  EXPECT_TRUE(wm::GetWindowState(w1.get())->can_be_dragged());
-  EXPECT_TRUE(wm::GetWindowState(w2.get())->can_be_dragged());
 }
 
 // Tests that windows that can control maximized bounds are not maximized
@@ -1717,4 +1730,20 @@ TEST_F(TabletModeWindowManagerTest, SetPropertyOnUnmanagedWindow) {
   window->Show();
 }
 
+// Test that there is no window resizer in tablet mode.
+TEST_F(TabletModeWindowManagerTest, NoWindowResizerInTabletMode) {
+  gfx::Rect rect(10, 10, 200, 200);
+  std::unique_ptr<aura::Window> window(
+      CreateWindow(aura::client::WINDOW_TYPE_NORMAL, rect));
+  std::unique_ptr<WindowResizer> resizer(CreateWindowResizer(
+      window.get(), gfx::Point(), HTCAPTION, ::wm::WINDOW_MOVE_SOURCE_MOUSE));
+  EXPECT_TRUE(resizer.get());
+  resizer.reset();
+
+  CreateTabletModeWindowManager();
+  resizer = CreateWindowResizer(window.get(), gfx::Point(), HTCAPTION,
+                                ::wm::WINDOW_MOVE_SOURCE_MOUSE);
+  EXPECT_FALSE(resizer.get());
+}
+
 }  // namespace ash
