@@ -8,13 +8,13 @@
 #include <map>
 #include <memory>
 
+#include "ash/public/cpp/ash_switches.h"
 #include "ash/public/cpp/shell_window_ids.h"
 #include "ash/shell.h"
 #include "ash/wm/mru_window_tracker.h"
 #include "ash/wm/window_mirror_view.h"
 #include "ash/wm/window_state.h"
 #include "ash/wm/window_util.h"
-#include "base/command_line.h"
 #include "ui/accessibility/ax_node_data.h"
 #include "ui/compositor/scoped_layer_animation_settings.h"
 #include "ui/display/display.h"
@@ -72,7 +72,8 @@ class WindowPreviewView : public views::View, public aura::WindowObserver {
         preview_background_(new views::View),
         mirror_view_(
             new wm::WindowMirrorView(window,
-                                     /*trilinear_filtering_on_init=*/true)),
+                                     /*trilinear_filtering_on_init=*/switches::
+                                         IsTrilinearFilteringEnabled())),
         window_observer_(this) {
     window_observer_.Add(window);
     window_title_->SetText(window->GetTitle());
