@@ -385,6 +385,15 @@ void WindowState::SetPreAddedToWorkspaceWindowBounds(const gfx::Rect& bounds) {
   pre_added_to_workspace_window_bounds_ = base::make_optional(bounds);
 }
 
+void WindowState::SetPersistentWindowInfo(
+    const PersistentWindowInfo& persistent_window_info) {
+  persistent_window_info_ = base::make_optional(persistent_window_info);
+}
+
+void WindowState::ResetPersistentWindowInfo() {
+  persistent_window_info_.reset();
+}
+
 void WindowState::AddObserver(WindowStateObserver* observer) {
   observer_list_.AddObserver(observer);
 }
@@ -432,6 +441,7 @@ void WindowState::set_bounds_changed_by_user(bool bounds_changed_by_user) {
   if (bounds_changed_by_user) {
     pre_auto_manage_window_bounds_.reset();
     pre_added_to_workspace_window_bounds_.reset();
+    persistent_window_info_.reset();
   }
 }
 
@@ -479,7 +489,6 @@ WindowState::WindowState(aura::Window* window)
       hide_shelf_when_fullscreen_(true),
       autohide_shelf_when_maximized_or_fullscreen_(false),
       minimum_visibility_(false),
-      can_be_dragged_(true),
       cached_always_on_top_(false),
       ignore_property_change_(false),
       current_state_(new DefaultState(ToWindowStateType(GetShowState()))) {
@@ -610,6 +619,13 @@ void WindowState::SetBoundsDirectCrossFade(const gfx::Rect& new_bounds) {
     return;
   }
 
+  // If the window already has a transform in place, do not use the cross fade
+  // animation, set the bounds directly instead.
+  if (!window_->layer()->GetTargetTransform().IsIdentity()) {
+    SetBoundsDirect(new_bounds);
+    return;
+  }
+
   // Create fresh layers for the window and all its children to paint into.
   // Takes ownership of the old layer and all its children, which will be
   // cleaned up after the animation completes.
@@ -686,5 +702,11 @@ void WindowState::OnWindowAddedToRootWindow(aura::Window* window) {
   MoveAllTransientChildrenToNewRoot(window);
 }
 
+void WindowState::OnWindowDestroying(aura::Window* window) {
+  DCHECK_EQ(window_, window);
+  current_state_->OnWindowDestroying(this);
+  delegate_.reset();
+}
+
 }  // namespace wm
 }  // namespace ash
