@@ -8,6 +8,7 @@
 #include <memory>
 
 #include "ash/ash_export.h"
+#include "ash/display/persistent_window_info.h"
 #include "ash/public/interfaces/window_state_type.mojom.h"
 #include "ash/wm/drag_details.h"
 #include "base/gtest_prod_util.h"
@@ -85,6 +86,9 @@ class ASH_EXPORT WindowState : public aura::WindowObserver {
     // Note: This only gets called when the state object gets changed.
     virtual void DetachState(WindowState* window_state) = 0;
 
+    // Called when the window is being destroyed.
+    virtual void OnWindowDestroying(WindowState* window_state) {}
+
    private:
     DISALLOW_COPY_AND_ASSIGN(State);
   };
@@ -236,25 +240,28 @@ class ASH_EXPORT WindowState : public aura::WindowObserver {
     minimum_visibility_ = minimum_visibility;
   }
 
-  // Specifies if the window can be dragged by the user via the caption or not.
-  bool can_be_dragged() const { return can_be_dragged_; }
-  void set_can_be_dragged(bool can_be_dragged) {
-    can_be_dragged_ = can_be_dragged;
-  }
-
   // Gets/Sets the bounds of the window before it was moved by the auto window
   // management. As long as it was not auto-managed, it will return NULL.
-  base::Optional<gfx::Rect> pre_auto_manage_window_bounds() const {
+  const base::Optional<gfx::Rect> pre_auto_manage_window_bounds() {
     return pre_auto_manage_window_bounds_;
   }
   void SetPreAutoManageWindowBounds(const gfx::Rect& bounds);
 
   // Gets/Sets the property that is used on window added to workspace event.
-  base::Optional<gfx::Rect> pre_added_to_workspace_window_bounds() const {
+  const base::Optional<gfx::Rect> pre_added_to_workspace_window_bounds() {
     return pre_added_to_workspace_window_bounds_;
   }
   void SetPreAddedToWorkspaceWindowBounds(const gfx::Rect& bounds);
 
+  // Gets/Sets the persistent window info that is used on restoring persistent
+  // window bounds in multi-displays scenario.
+  const base::Optional<PersistentWindowInfo> persistent_window_info() {
+    return persistent_window_info_;
+  }
+  void SetPersistentWindowInfo(
+      const PersistentWindowInfo& persistent_window_info);
+  void ResetPersistentWindowInfo();
+
   // Layout related properties
 
   void AddObserver(WindowStateObserver* observer);
@@ -400,6 +407,7 @@ class ASH_EXPORT WindowState : public aura::WindowObserver {
                                const void* key,
                                intptr_t old) override;
   void OnWindowAddedToRootWindow(aura::Window* window) override;
+  void OnWindowDestroying(aura::Window* window) override;
 
   // The owner of this window settings.
   aura::Window* window_;
@@ -415,7 +423,6 @@ class ASH_EXPORT WindowState : public aura::WindowObserver {
   bool hide_shelf_when_fullscreen_;
   bool autohide_shelf_when_maximized_or_fullscreen_;
   bool minimum_visibility_;
-  bool can_be_dragged_;
   bool cached_always_on_top_;
   bool allow_set_bounds_direct_ = false;
 
@@ -433,6 +440,11 @@ class ASH_EXPORT WindowState : public aura::WindowObserver {
   // nullptr, and window is removing from a workspace.
   base::Optional<gfx::Rect> pre_added_to_workspace_window_bounds_;
 
+  // A property to remember the persistent window info used in multi-displays
+  // scenario to attempt to restore windows to their original bounds when
+  // displays are restored to their previous states.
+  base::Optional<PersistentWindowInfo> persistent_window_info_;
+
   base::ObserverList<WindowStateObserver> observer_list_;
 
   // True to ignore a property change event to avoid reentrance in
