@@ -375,6 +375,19 @@ class BBJSONGenerator(object):
       self.clean_swarming_dictionary(test['swarming'])
     return test
 
+  def add_common_test_properties(self, test, tester_config):
+    if tester_config.get('use_multi_dimension_trigger_script'):
+      test['trigger_script'] = {
+        'script': '//testing/trigger_scripts/trigger_multiple_dimensions.py',
+        'args': [
+          '--multiple-trigger-configs',
+          json.dumps(tester_config['swarming']['dimension_sets'] +
+                     tester_config.get('alternate_swarming_dimensions', [])),
+          '--multiple-dimension-script-verbose',
+          'True'
+        ],
+      }
+
   def generate_gtest(self, waterfall, tester_name, tester_config, test_name,
                      test_config):
     if not self.should_run_on_tester(
@@ -429,6 +442,7 @@ class BBJSONGenerator(object):
 
     result = self.update_and_cleanup_test(result, test_name, tester_name,
                                           waterfall)
+    self.add_common_test_properties(result, tester_config)
     return result
 
   def generate_isolated_script_test(self, waterfall, tester_name, tester_config,
@@ -442,6 +456,7 @@ class BBJSONGenerator(object):
     self.initialize_swarming_dictionary_for_test(result, tester_config)
     result = self.update_and_cleanup_test(result, test_name, tester_name,
                                           waterfall)
+    self.add_common_test_properties(result, tester_config)
     return result
 
   def generate_script_test(self, waterfall, tester_name, tester_config,
