@@ -48,6 +48,36 @@ FOO_GTESTS_WATERFALL = """\
 ]
 """
 
+FOO_GTESTS_MULTI_DIMENSION_WATERFALL = """\
+[
+  {
+    'name': 'chromium.test',
+    'machines': {
+      'Fake Tester': {
+        'swarming': {
+          'dimension_sets': [
+            {
+              "gpu": "none",
+              "os": "1",
+            },
+          ],
+        },
+        'use_multi_dimension_trigger_script': True,
+        'alternate_swarming_dimensions': [
+          {
+            "gpu": "none",
+            "os": "2",
+          },
+        ],
+        'test_suites': {
+          'gtest_tests': 'foo_tests',
+        },
+      },
+    },
+  },
+]
+"""
+
 COMPOSITION_GTEST_SUITE_WATERFALL = """\
 [
   {
@@ -840,6 +870,41 @@ ANDROID_WATERFALL_OUTPUT = """\
 }
 """
 
+MULTI_DIMENSION_OUTPUT = """\
+{
+  "AAAAA1 AUTOGENERATED FILE DO NOT EDIT": {},
+  "AAAAA2 See generate_buildbot_json.py to make changes": {},
+  "Fake Tester": {
+    "gtest_tests": [
+      {
+        "swarming": {
+          "can_use_on_swarming_builders": true,
+          "dimension_sets": [
+            {
+              "gpu": "none",
+              "integrity": "high",
+              "os": "1"
+            }
+          ],
+          "expiration": 120
+        },
+        "test": "foo_test",
+        "trigger_script": {
+          "args": [
+            "--multiple-trigger-configs",
+            "[{\\"gpu\\": \\"none\\", \\"os\\": \\"1\\"}, \
+{\\"gpu\\": \\"none\\", \\"os\\": \\"2\\"}]",
+            "--multiple-dimension-script-verbose",
+            "True"
+          ],
+          "script": "//testing/trigger_scripts/trigger_multiple_dimensions.py"
+        }
+      }
+    ]
+  }
+}
+"""
+
 class UnitTest(unittest.TestCase):
   def test_base_generator(self):
     # Only needed for complete code coverage.
@@ -856,6 +921,12 @@ class UnitTest(unittest.TestCase):
                     EMPTY_EXCEPTIONS)
     fbb.check_input_file_consistency()
 
+  def test_good_multi_dimension_test_suites_are_ok(self):
+    fbb = FakeBBGen(FOO_GTESTS_MULTI_DIMENSION_WATERFALL,
+                    FOO_TEST_SUITE,
+                    EMPTY_EXCEPTIONS)
+    fbb.check_input_file_consistency()
+
   def test_good_composition_test_suites_are_ok(self):
     fbb = FakeBBGen(COMPOSITION_GTEST_SUITE_WATERFALL,
                     GOOD_COMPOSITION_TEST_SUITES,
@@ -1033,6 +1104,13 @@ class UnitTest(unittest.TestCase):
     fbb.files['chromium.test.json'] = COMPOSITION_WATERFALL_WITH_ARGS_OUTPUT
     fbb.check_output_file_consistency(verbose=True)
 
+  def test_multi_dimension_output(self):
+    fbb = FakeBBGen(FOO_GTESTS_MULTI_DIMENSION_WATERFALL,
+                    FOO_TEST_SUITE,
+                    EMPTY_EXCEPTIONS)
+    fbb.files['chromium.test.json'] = MULTI_DIMENSION_OUTPUT
+    fbb.check_output_file_consistency(verbose=True)
+
 
 if __name__ == '__main__':
   unittest.main()
