@@ -14,13 +14,16 @@ import common
 
 
 def main_run(args):
-  rc = common.run_command([
+  command_line = [
       sys.executable,
       os.path.join(common.SRC_DIR, 'tools', 'traffic_annotation', 'scripts',
                    'check_annotations.py'),
       '--build-path',
       os.path.join(args.paths['checkout'], 'out', args.build_config_fs),
-  ])
+  ]
+  if '--end-to-end' in args:
+    command_line += ['--complete']
+  rc = common.run_command(command_line)
 
   json.dump({
       'valid': True,
@@ -31,7 +34,8 @@ def main_run(args):
 
 
 def main_compile_targets(args):
-  json.dump(['chrome'], args.output)
+  json.dump(['chrome', 'remoting/host:host', 'remoting/client:client'],
+            args.output)
 
 
 if __name__ == '__main__':
